@@ -55,10 +55,11 @@ void AboutDialog::CreateCreditsList()
 {
    // The Audacity 1.3.x and 2.0.x team: developers and support
    AddCredit(wxT("Richard Ash"), roleTeamDeveloper);
-   AddCredit(wxT("Michael Chinen"), roleTeamDeveloper);
    AddCredit(wxT("James Crook"), roleTeamDeveloper);
    AddCredit(wxString(wxT("Roger Dannenberg - ")) + _("co-founder"), roleTeamDeveloper);
+   AddCredit(wxT("Benjamin Drung"), roleTeamDeveloper);
    AddCredit(wxT("Vaughan Johnson"), roleTeamDeveloper);
+   AddCredit(wxT("Leland Lucius"), roleTeamDeveloper);
    AddCredit(wxT("Martyn Shaw"), roleTeamDeveloper);
 
    AddCredit(wxString(wxT("Gale Andrews - ")) + _("quality assurance"), roleTeamSupport);
@@ -73,10 +74,10 @@ void AboutDialog::CreateCreditsList()
    // longer active.
  
    AddCredit(wxT("Matt Brubeck"), roleEmeritusDeveloper);
+   AddCredit(wxT("Michael Chinen"), roleEmeritusDeveloper);
    AddCredit(wxT("Al Dimond"), roleEmeritusDeveloper);
    AddCredit(wxT("Joshua Haberman"), roleEmeritusDeveloper);
    AddCredit(wxT("Ruslan Ijbulatov"), roleEmeritusDeveloper);
-   AddCredit(wxT("Leland Lucius"), roleEmeritusDeveloper);
    AddCredit(wxString(wxT("Dominic Mazzoni - "))+_("co-founder"), roleEmeritusDeveloper);
    AddCredit(wxT("Markus Meyer"), roleEmeritusDeveloper);
    AddCredit(wxT("Monty Montgomery"), roleEmeritusDeveloper);
@@ -89,44 +90,58 @@ void AboutDialog::CreateCreditsList()
    AddCredit(wxT("Lynn Allan"), roleContributor);
    AddCredit(wxT("David Bailes"), roleContributor);
    AddCredit(wxT("William Bland"), roleContributor);
+   AddCredit(wxT("Jeremy R. Brown"), roleContributor);
+   AddCredit(wxT("Alex S. Brown"), roleContributor);
    AddCredit(wxT("Chris Cannam"), roleContributor);
+   AddCredit(wxT("Craig DeForest"), roleContributor);
+   AddCredit(wxT("Mitch Golden"), roleContributor);
    AddCredit(wxT("Brian Gunlogson"), roleContributor);
    AddCredit(wxT("Daniel Horgan"), roleContributor);
+   AddCredit(wxT("David Hostetler"), roleContributor);
+   AddCredit(wxT("Steve Jolly"), roleContributor);
+   AddCredit(wxT("Steven Jones"), roleContributor);
    AddCredit(wxT("Arun Kishore"), roleContributor);
    AddCredit(wxT("Paul Livesey"), roleContributor);
    AddCredit(wxT("Harvey Lubin"), roleContributor);
    AddCredit(wxT("Greg Mekkes"), roleContributor);
    AddCredit(wxT("Abe Milde"), roleContributor);
-   AddCredit(wxT("Paul Nasca"), roleContributor);
+   AddCredit(wxT("<a href=\"http://www.paulnasca.com/\">Paul Nasca</a>"), roleContributor);
+   AddCredit(wxT("Clayton Otey"), roleContributor);
    AddCredit(wxT("Andr\u00e9 Pinto"), roleContributor);
+   AddCredit(wxT("Mark Phillips"), roleContributor);
+   AddCredit(wxT("Jean Claude Risset"), roleContributor);
+   AddCredit(wxT("Edgar-RFT"), roleContributor);
    AddCredit(wxT("Augustus Saunders"), roleContributor);
+   AddCredit(wxT("Benjamin Schwartz"), roleContributor);
    AddCredit(wxT("David R. Sky"), roleContributor);
+   AddCredit(wxT("Rob Sykes"), roleContributor);
    AddCredit(wxT("Mike Underwood"), roleContributor);
+   AddCredit(wxT("Philip Van Baren"), roleContributor);
+   AddCredit(wxT("Salvo Ventura"), roleContributor);
    AddCredit(wxT("Jun Wan"), roleContributor);
    AddCredit(wxT("Tom Woodhams"), roleContributor);
    AddCredit(wxT("Wing Yu"), roleContributor);
    
    AddCredit(wxT("expat"), roleLibrary);
    AddCredit(wxT("FLAC"), roleLibrary);
-   AddCredit(wxT("iAVC"), roleLibrary);
    AddCredit(wxT("LAME"), roleLibrary);
    AddCredit(wxT("libmad"), roleLibrary);
    #if USE_LIBRESAMPLE
-      AddCredit(wxT("libresample"), roleLibrary);
+      AddCredit(wxT("libresample, by Dominic Mazzoni and Julius Smith"), roleLibrary);
    #endif
    #if USE_LIBSAMPLERATE
-      AddCredit(wxT("libsamplerate"), roleLibrary);
+      AddCredit(wxT("libsamplerate, by Erik de Castro Lopo"), roleLibrary);
    #endif
    #if USE_LIBSOXR
-      AddCredit(wxT("libsoxr"), roleLibrary);
+      AddCredit(wxT("libsoxr, by Rob Sykes"), roleLibrary);
    #endif
    AddCredit(wxT("libsndfile"), roleLibrary);
    AddCredit(wxT("Nyquist"), roleLibrary);
    AddCredit(wxT("Ogg Vorbis"), roleLibrary);
    AddCredit(wxT("PortAudio"), roleLibrary);
    AddCredit(wxT("portsmf"), roleLibrary);
-   AddCredit(wxT("sbsms"), roleLibrary);
-   AddCredit(wxT("SoundTouch"), roleLibrary);
+   AddCredit(wxT("sbsms, by Clayton Otey"), roleLibrary);
+   AddCredit(wxT("<a href=\"http://www.surina.net/soundtouch/\">SoundTouch</a>, by Olli Parviainen"), roleLibrary);
    AddCredit(wxT("TwoLAME"), roleLibrary);
    AddCredit(wxT("Vamp"), roleLibrary);
    AddCredit(wxT("wxWidgets"), roleLibrary);
@@ -134,7 +149,6 @@ void AboutDialog::CreateCreditsList()
    AddCredit(wxT("Dave Beydler"), roleThanks);
    AddCredit(wxT("Brian Cameron"), roleThanks);
    AddCredit(wxT("Jason Cohen"), roleThanks);
-   AddCredit(wxT("Benjamin Drung"), roleThanks);
    AddCredit(wxT("Dave Fancella"), roleThanks);
    AddCredit(wxT("Steve Harris"), roleThanks);
    AddCredit(wxT("Daniel James"), roleThanks);
@@ -143,7 +157,6 @@ void AboutDialog::CreateCreditsList()
    AddCredit(wxT("Logan Lewis"), roleThanks);
    AddCredit(wxT("David Luff"), roleThanks);
    AddCredit(wxT("Jason Pepas"), roleThanks);
-   AddCredit(wxT("Mark Phillips"), roleThanks);
    AddCredit(wxT("Jonathan Ryshpan"), roleThanks);
    AddCredit(wxT("Michael Schwendt"), roleThanks);
    AddCredit(wxT("Patrick Shirkey"), roleThanks);
@@ -196,19 +209,18 @@ AboutDialog::AboutDialog(wxWindow * parent)
 
 void AboutDialog::PopulateAudacityPage( ShuttleGui & S )
 {
-   wxString versionStr = AUDACITY_VERSION_STRING;
-
-
-   creditItems.DeleteContents(true); // switchon automatic deletion of list items
+   creditItems.DeleteContents(true); // Switch on automatic deletion of list items.
    CreateCreditsList();
-   
 
    wxString par1Str = _(
-     "Audacity is a free program written by a worldwide team of volunteer <a href=\"http://audacity.sourceforge.net/community/developers\">developers</a>. We thank <a href=\"http://sourceforge.net\">SourceForge.net</a> and <a href=\"http://code.google.com\">Google Code</a> for our project hosting. Audacity is <a href=\"http://audacity.sourceforge.net/download/\">available</a> for Windows, Mac, and GNU/Linux (and other Unix-like systems).");
+"Audacity is a free program written by a worldwide team of volunteer <a href=\"http://audacity.sourceforge.net/community/developers\">developers</a>. \
+We thank <a href=\"http://code.google.com\">Google Code</a> and <a href=\"http://sourceforge.net\">SourceForge</a> for hosting our project. \
+Audacity is <a href=\"http://audacity.sourceforge.net/download/\">available</a> for Windows, Mac, and GNU/Linux (and other Unix-like systems).");
 
-   // No such thing as an official released 'beta' anymore, so keep this string simple.
    wxString par2Str = _(
-     "If you find a bug or have a suggestion for us, please write to our <a href=\"mailto:feedback@audacityteam.org\">Feedback</a> address. For help, view the tips and tricks on our <a href=\"http://wiki.audacityteam.org/\">Wiki</a> or visit our <a href=\"http://forum.audacityteam.org/\">Forum</a>.");
+"If you find a bug or have a suggestion for us, please write to our <a href=\"mailto:feedback@audacityteam.org\">feedback address</a>. \
+For help, view the tips and tricks on our <a href=\"http://wiki.audacityteam.org/\">wiki</a> or \
+visit our <a href=\"http://forum.audacityteam.org/\">forum</a>.");
 
    wxString translatorCredits;
    /* i18n-hint: The translation of "translator_credits" will appear
@@ -216,10 +228,9 @@ void AboutDialog::PopulateAudacityPage( ShuttleGui & S )
     *  your own name(s) to the credits.
     *
     *  For example:  "English translation by Dominic Mazzoni." */
-   if (_("translator_credits") != wxString(wxT("translator_credits"))) {
-      translatorCredits += wxT("<p><center>");
-      translatorCredits += _("translator_credits");
-      translatorCredits += wxT("</center>");
+   if (_("translator_credits") != wxString(wxT("translator_credits"))) 
+   {
+      translatorCredits = _("translator_credits");
    }
    wxString localeStr = wxLocale::GetSystemEncodingName();
 
@@ -228,59 +239,41 @@ void AboutDialog::PopulateAudacityPage( ShuttleGui & S )
          localeStr + 
          wxT("\"></head>") + 
       wxT("<body bgcolor=\"#ffffff\"><center>") + 
-      wxT("<h3>Audacity ") + versionStr + wxT("</h3>")+ 
-      _("A Free Digital Audio Editor<br>") + 
-	  wxT("<a href=\"http://audacity.sourceforge.net/\">http://audacity.sourceforge.net/</a>") +
-      wxT("</center><p>") + par1Str +
+      wxT("<h3>Audacity ") + wxString(AUDACITY_VERSION_STRING) + wxT("</h3>")+ 
+      _("free, open source, cross-platform software for recording and editing sounds<br>") + 
+      wxT("<a href=\"http://audacity.sourceforge.net/\">http://audacity.sourceforge.net/</a>") +
+      wxT("<p><br>") + par1Str +
       wxT("<p>") + par2Str +
-      wxT("<p><center><b>") + _("Credits") + wxT("</b></center>")
-      + translatorCredits +
-      wxT("<p><center><b>") +
+      wxT("<h3>") + _("Credits") + wxT("</h3>") + 
+      wxT("<p>") + translatorCredits +
 
-      /* i18n-hint: %s will be replaced by the version number.*/
-      wxString::Format(_("Audacity %s Development Team"), versionStr.c_str()) +
-      wxT("</b><br>") +
+      wxT("<p><b>") + wxString::Format(_("Audacity Developers")) + wxT("</b><br>") +
       GetCreditsByRole(roleTeamDeveloper) +
-      wxT("<p><br><b>") +
 
-      /* i18n-hint: %s will be replaced by the version number.*/
-      wxString::Format(_("Audacity %s Support Team"), versionStr.c_str()) +
-      wxT("</b><br>") +
+      wxT("<p><b>") + wxString::Format(_("Audacity Support Team")) + wxT("</b><br>") +
       GetCreditsByRole(roleTeamSupport) +
-      wxT("<p><br><b>") +
 
-      _("Emeritus Developers") +
-      wxT("</b><br>") +
+      wxT("<p><b>") + _("Emeritus Developers") + wxT("</b><br>") +
       GetCreditsByRole(roleEmeritusDeveloper) +
-      wxT("<p><br><b>") +
-
-      _("Other Emeritus Team Members") +
-      wxT("</b><br>") +
+      
+      wxT("<p><b>") + _(" Emeritus Team Members") + wxT("</b><br>") +
       GetCreditsByRole(roleEmeritusSupport) +
-      wxT("<p><br><b>") +
 
-      _("Other Contributors") +
-      wxT("</b><br>") +
+      wxT("<p><b>") + _("Other Contributors") + wxT("</b><br>") +
       GetCreditsByRole(roleContributor) +
-      wxT("<p><br><b>") +
 
-      _("Audacity is based on code from the following projects:") +
-      wxT("</b><br>") +
+      wxT("<p><b>") +  _("Audacity is based on code from the following projects:") + wxT("</b><br>") +
       GetCreditsByRole(roleLibrary) +
-      wxT("<p><br><b>") +
-
-      _("Special thanks:") +
-      wxT("</b><br>") +
+      
+      wxT("<p><b>") +  _("Special thanks:") + wxT("</b><br>") +
       GetCreditsByRole(roleThanks) +
-      wxT("<p><br></center>") +
-	  
-      _("<b>Audacity&reg;</b> software is copyright")+
+      
+      wxT("<p><br>") + _("<b>Audacity&reg;</b> software is copyright")+
       wxT("&copy; 1999-2013 Audacity Team.<br>") +
-     
       _("The name <b>Audacity&reg;</b> is a registered trademark of Dominic Mazzoni.") + 
-      wxT("</font></body></html>");
+      wxT("</center></font></body></html>");
+
 
-   
    this->SetBackgroundColour(theTheme.Colour( clrAboutBoxBackground ));
 
 
