@@ -25,6 +25,7 @@ It handles initialization and termination by subclassing wxApp.
 
 #include <wx/defs.h>
 #include <wx/app.h>
+#include <wx/bitmap.h>
 #include <wx/docview.h>
 #include <wx/event.h>
 #include <wx/ipc.h>
@@ -34,6 +35,7 @@ It handles initialization and termination by subclassing wxApp.
 #include <wx/menu.h>
 #include <wx/msgdlg.h>
 #include <wx/snglinst.h>
+#include <wx/splash.h>
 #include <wx/sysopt.h>
 #include <wx/fontmap.h>
 
@@ -204,6 +206,8 @@ It handles initialization and termination by subclassing wxApp.
 
 #endif //(__WXMSW__)
 
+#include "../images/AudacityLogoWithName.xpm"
+
 ////////////////////////////////////////////////////////////
 /// Custom events
 ////////////////////////////////////////////////////////////
@@ -214,7 +218,7 @@ DEFINE_EVENT_TYPE(EVT_RELEASE_KEYBOARD);
 DEFINE_EVENT_TYPE(EVT_CAPTURE_KEY);
 
 #ifdef __WXGTK__
-void wxOnAssert(const wxChar *fileName, int lineNumber, const wxChar *msg)
+static void wxOnAssert(const wxChar *fileName, int lineNumber, const wxChar *msg)
 {
    if (msg)
       printf("ASSERTION FAILED: %s\n%s: %d\n", (const char *)wxString(msg).mb_str(), (const char *)wxString(fileName).mb_str(), lineNumber);
@@ -232,7 +236,7 @@ void wxOnAssert(const wxChar *fileName, int lineNumber, const wxChar *msg)
 
 static wxFrame *gParentFrame = NULL;
 
-bool gInited = false;
+static bool gInited = false;
 bool gIsQuitting = false;
 
 void QuitAudacity(bool bForce)
@@ -407,6 +411,11 @@ void SaveWindowSize()
 // Most of this was taken from nsNativeAppSupportUnix.cpp from Mozilla.
 ///////////////////////////////////////////////////////////////////////////////
 
+// TODO: May need updating.  Is this code too obsolete (relying on Gnome2 so's) to be 
+// worth keeping anymore?  
+// CB suggests we use libSM directly ref:
+// http://www.x.org/archive/X11R7.7/doc/libSM/SMlib.html#The_Save_Yourself_Callback
+
 #include <dlfcn.h>
 /* There is a conflict between the type names used in Glib >= 2.21 and those in
  * wxGTK (http://trac.wxwidgets.org/ticket/10883)
@@ -461,10 +470,10 @@ typedef void (*_gnome_interaction_key_return_fn)(gint, gboolean);
 static _gnome_client_request_interaction_fn gnome_client_request_interaction;
 static _gnome_interaction_key_return_fn gnome_interaction_key_return;
 
-void interact_cb(GnomeClient *client,
-                 gint key,
-                 GnomeDialogType type,
-                 gpointer data)
+static void interact_cb(GnomeClient *client,
+                        gint key,
+                        GnomeDialogType type,
+                        gpointer data)
 {
    wxCloseEvent e(wxEVT_QUERY_END_SESSION, wxID_ANY);
    e.SetEventObject(&wxGetApp());
@@ -475,13 +484,13 @@ void interact_cb(GnomeClient *client,
    gnome_interaction_key_return(key, e.GetVeto());
 }
 
-gboolean save_yourself_cb(GnomeClient *client,
-                          gint phase,
-                          GnomeSaveStyle style,
-                          gboolean shutdown,
-                          GnomeInteractStyle interact,
-                          gboolean fast,
-                          gpointer user_data)
+static gboolean save_yourself_cb(GnomeClient *client,
+                                 gint phase,
+                                 GnomeSaveStyle style,
+                                 gboolean shutdown,
+                                 GnomeInteractStyle interact,
+                                 gboolean fast,
+                                 gpointer user_data)
 {
    if (!shutdown || interact != GNOME_INTERACT_ANY) {
       return TRUE;
@@ -563,6 +572,8 @@ class GnomeShutdown
    GnomeClient *mClient;
 };
 
+// This variable exists to call the constructor and
+// connect a signal for the 'save-yourself' message.
 GnomeShutdown GnomeShutdownInstance;
 
 #endif
@@ -589,10 +600,10 @@ public:
    {
    };
 
-   bool OnExecute(const wxString & topic,
+   bool OnExecute(const wxString & WXUNUSED(topic),
                   wxChar *data,
-                  int size,
-                  wxIPCFormat format)
+                  int WXUNUSED(size),
+                  wxIPCFormat WXUNUSED(format))
    {
       if (!gInited) {
          return false;
@@ -641,35 +652,54 @@ public:
 
 #endif //__WXMSW__
 
+#ifndef __WXMAC__
 IMPLEMENT_APP(AudacityApp)
 /* make the application class known to wxWidgets for dynamic construction */
+#endif
+
+#ifdef __WXMAC__
+// This should be removed when Lame and FFmpeg support is converted
+// from loadable libraries to commands.mLogger
+//
+// The purpose of this is to give the user more control over where libraries
+// such as Lame and FFmpeg get loaded from.
+//
+// Since absolute pathnames are used when loading these libraries, the normal search
+// path would be DYLD_LIBRARY_PATH, absolute path, DYLD_FALLBACK_LIBRARY_PATH.  This
+// means that DYLD_LIBRARY_PATH can override what the user actually wants.
+//
+// So, we simply clear DYLD_LIBRARY_PATH to allow the users choice to be the first
+// one tried.
+IMPLEMENT_APP_NO_MAIN(AudacityApp)
+IMPLEMENT_WX_THEME_SUPPORT
+int main(int argc, char *argv[])
+{
+   if (getenv("DYLD_LIBRARY_PATH")) {
+      extern char **environ;
+
+      unsetenv("DYLD_LIBRARY_PATH");
+      execve(argv[0], argv, environ);
+   }
+   return wxEntry(argc, argv);
+}
+#endif
 
 #ifdef __WXMAC__
 
-#include <wx/recguard.h>
+// Where drag/drop or "Open With" filenames get stored until
+// the timer routine gets around to picking them up.
+static wxArrayString ofqueue;
 
 // in response of an open-document apple event
 void AudacityApp::MacOpenFile(const wxString &fileName)
 {
-   if (!gInited) {
-      return;
-   }
-
-   wxCommandEvent e(EVT_OPEN_AUDIO_FILE);
-   e.SetString(fileName);
-   AddPendingEvent(e);
+   ofqueue.Add(fileName);
 }
 
 // in response of a print-document apple event
 void AudacityApp::MacPrintFile(const wxString &fileName)
 {
-   if (!gInited) {
-      return;
-   }
-
-   wxCommandEvent e(EVT_OPEN_AUDIO_FILE);
-   e.SetString(fileName);
-   AddPendingEvent(e);
+   ofqueue.Add(fileName);
 }
 
 // in response of a open-application apple event
@@ -686,32 +716,6 @@ void AudacityApp::MacNewFile()
    }
 }
 
-// in response of a reopen-application apple event
-void AudacityApp::MacReopenApp()
-{
-   // Not sure what to do here...bring it to the foreground???
-}
-
-void AudacityApp::OnMacOpenFile(wxCommandEvent & event)
-{
-   // Add name to queue
-   static wxArrayString ofqueue;
-   ofqueue.Add(event.GetString());
-
-   // Do not attempt to load more than one file at a time
-   static wxRecursionGuardFlag guardflag;
-   wxRecursionGuard guard(guardflag);
-   if (guard.IsInside()) {
-      return;
-   }
-
-   // Load each file on the queue
-   while (ofqueue.GetCount()) {
-      wxString name(ofqueue[0]);
-      ofqueue.RemoveAt(0);
-      MRUOpen(name); // FIX-ME: Check the return result?
-   }
-}
 #endif //__WXMAC__
 
 typedef int (AudacityApp::*SPECIALKEYEVENT)(wxKeyEvent&);
@@ -736,8 +740,6 @@ BEGIN_EVENT_TABLE(AudacityApp, wxApp)
    EVT_MENU(wxID_ABOUT, AudacityApp::OnMenuAbout)
    EVT_MENU(wxID_PREFERENCES, AudacityApp::OnMenuPreferences)
    EVT_MENU(wxID_EXIT, AudacityApp::OnMenuExit)
-
-   EVT_COMMAND(wxID_ANY, EVT_OPEN_AUDIO_FILE, AudacityApp::OnMacOpenFile)
 #endif
    // Recent file event handlers.  
    EVT_MENU(ID_RECENT_CLEAR, AudacityApp::OnMRUClear)
@@ -748,6 +750,9 @@ BEGIN_EVENT_TABLE(AudacityApp, wxApp)
 END_EVENT_TABLE()
 
 // backend for OnMRUFile 
+// TODO: Would be nice to make this handle not opening a file with more panache.
+//  - Inform the user if DefaultOpenPath not set.
+//  - Switch focus to correct instance of project window, if already open.
 bool AudacityApp::MRUOpen(wxString fullPathStr) {
    // Most of the checks below are copied from AudacityProject::OpenFiles.
    // - some rationalisation might be possible.
@@ -766,7 +771,7 @@ bool AudacityApp::MRUOpen(wxString fullPathStr) {
          // Make sure it isn't already open.
          // Test here even though AudacityProject::OpenFile() also now checks, because 
          // that method does not return the bad result. 
-         // That itself may be a FIX-ME.
+         // That itself may be a FIXME.
          if (AudacityProject::IsAlreadyOpen(fullPathStr))
             return false;
          
@@ -798,7 +803,7 @@ bool AudacityApp::MRUOpen(wxString fullPathStr) {
    return(true);
 }
 
-void AudacityApp::OnMRUClear(wxCommandEvent& event)
+void AudacityApp::OnMRUClear(wxCommandEvent& WXUNUSED(event))
 {
    mRecentFiles->Clear();
 }
@@ -819,8 +824,30 @@ void AudacityApp::OnMRUFile(wxCommandEvent& event) {
       mRecentFiles->RemoveFileFromHistory(n);
 }
 
-void AudacityApp::OnTimer(wxTimerEvent& event)
+void AudacityApp::OnTimer(wxTimerEvent& WXUNUSED(event))
 {
+#if defined(__WXMAC__)
+   // Filenames are queued when Audacity receives the a few of the 
+   // AppleEvent messages (via wxWidgets).  So, open any that are
+   // in the queue and clean the queue.
+   if (ofqueue.GetCount()) {
+      // Load each file on the queue
+      while (ofqueue.GetCount()) {
+         wxString name(ofqueue[0]);
+         ofqueue.RemoveAt(0);
+         // TODO: Handle failures better.
+         // Some failures are OK, e.g. file not found, just would-be-nices to do better,
+         // so FAIL_MSG is more a case of an enhancement request than an actual  problem.
+         // LL:  In all but one case an appropriate message is already displayed.  The
+         //      instance that a message is NOT displayed is when a failure to write
+         //      to the config file has occurred.
+         if (!MRUOpen(name)) {
+            wxFAIL_MSG(wxT("MRUOpen failed"));
+         }
+      }
+   }
+#endif
+ 
    // Check if a warning for missing aliased files should be displayed
    if (ShouldShowMissingAliasedFileWarning()) {
       // find which project owns the blockfile
@@ -914,46 +941,45 @@ void AudacityApp::InitLang( const wxString & lang )
    if( mLocale )
       delete mLocale;
 
-   if (lang != wxT("en")) 
-   {
 // LL: I do not know why loading translations fail on the Mac if LANG is not
 //     set, but for some reason it does.  So wrap the creation of wxLocale
 //     with the default translation.
+//
+//     2013-09-13:  I've checked this again and it is still required.  Still
+//                  no idea why.
 #if defined(__WXMAC__)
-      wxString oldval;
-      bool existed;
-      
-      existed = wxGetEnv(wxT("LANG"), &oldval);
-      wxSetEnv(wxT("LANG"), wxT("en_US"));
+   wxString oldval;
+   bool existed;
+
+   existed = wxGetEnv(wxT("LANG"), &oldval);
+   wxSetEnv(wxT("LANG"), wxT("en_US"));
 #endif
 
-      mLocale = new wxLocale(wxT(""), lang, wxT(""), true, true);
+   mLocale = new wxLocale(wxT(""), lang, wxT(""), true, true);
 
 #if defined(__WXMAC__)
-      if (existed) {
-         wxSetEnv(wxT("LANG"), oldval);
-      }
-      else {
-         wxUnsetEnv(wxT("LANG"));
-      }
+   if (existed) {
+      wxSetEnv(wxT("LANG"), oldval);
+   }
+   else {
+      wxUnsetEnv(wxT("LANG"));
+   }
 #endif
 
-      for(unsigned int i=0; i<audacityPathList.GetCount(); i++)
-         mLocale->AddCatalogLookupPathPrefix(audacityPathList[i]);
+   for(unsigned int i=0; i<audacityPathList.GetCount(); i++)
+      mLocale->AddCatalogLookupPathPrefix(audacityPathList[i]);
 
-      // LL:  Must add the wxWidgets catalog manually since the search
-      //      paths were not set up when mLocale was created.  The
-      //      catalogs are search in LIFO order, so add wxstd first.
-      mLocale->AddCatalog(wxT("wxstd"));
+   // LL:  Must add the wxWidgets catalog manually since the search
+   //      paths were not set up when mLocale was created.  The
+   //      catalogs are search in LIFO order, so add wxstd first.
+   mLocale->AddCatalog(wxT("wxstd"));
 
 // AUDACITY_NAME is legitimately used on some *nix configurations. 
 #ifdef AUDACITY_NAME
-      mLocale->AddCatalog(wxT(AUDACITY_NAME));
+   mLocale->AddCatalog(wxT(AUDACITY_NAME));
 #else
-      mLocale->AddCatalog(IPC_APPL);
+   mLocale->AddCatalog(IPC_APPL);
 #endif
-   } else
-      mLocale = NULL;
 
    // Initialize internationalisation (number formats etc.)
    //
@@ -968,6 +994,30 @@ void AudacityApp::OnFatalException()
    exit(-1);
 }
 
+#if defined(__WXGTK__)
+// On wxGTK, there's a focus issue where dialogs do not automatically pass focus
+// to the first child.  This means that you can use the keyboard to navigate within
+// the dialog.  Watching for the ACTIVATE event allows us to set the focus ourselves
+// when each dialog opens.
+//
+// See bug #57
+//
+int AudacityApp::FilterEvent(wxEvent & event)
+{
+   if (event.GetEventType() == wxEVT_ACTIVATE)
+   {
+      wxActivateEvent & e = (wxActivateEvent &) event;
+      
+      if (e.GetEventObject() && e.GetActive() && e.GetEventObject()->IsKindOf(CLASSINFO(wxDialog)))
+      {
+         ((wxWindow *)e.GetEventObject())->SetFocus();
+      }
+   }
+
+   return -1;
+}
+#endif
+
 // The `main program' equivalent, creating the windows and returning the
 // main frame
 bool AudacityApp::OnInit()
@@ -985,13 +1035,6 @@ bool AudacityApp::OnInit()
    wxSystemOptions::SetOption( wxMAC_WINDOW_PLAIN_TRANSITION, 1 );
 #endif
 
-#ifdef CLEANSPEECH
-//MERGE:
-//Everything now uses Audacity name for preferences.
-//(Audacity and CleanSpeech the same program and use
-//the same preferences file).
-//
-#endif   // CLEANSPEECH
 // LL: Moved here from InitPreferences() to ensure VST effect
 //     discovery writes configuration to the correct directory
 //     on OSX with case-sensitive file systems.
@@ -1053,9 +1096,6 @@ bool AudacityApp::OnInit()
    //
 
    wxString home = wxGetHomeDir();
-#ifdef CLEANSPEECH
-   mAppHomeDir = home;
-#endif   // CLEANSPEECH
    theTheme.EnsureInitialised();
 
    // AColor depends on theTheme.
@@ -1135,17 +1175,26 @@ bool AudacityApp::OnInit()
    #endif //__WXMAC__
 
    // BG: Create a temporary window to set as the top window
-   wxFrame *temporarywindow = new wxFrame(NULL, -1, wxT("temporarytopwindow"));
+   wxImage logoimage((const char **) AudacityLogoWithName_xpm);
+   logoimage.Rescale(logoimage.GetWidth() / 2, logoimage.GetHeight() / 2);
+   wxBitmap logo(logoimage);
+   wxSplashScreen *temporarywindow =
+      new wxSplashScreen(logo,
+                         wxSPLASH_CENTRE_ON_SCREEN | wxSPLASH_NO_TIMEOUT,
+                         0,
+                         NULL,
+                         wxID_ANY,
+                         wxDefaultPosition,
+                         wxDefaultSize,
+                         wxSTAY_ON_TOP);
+   temporarywindow->SetTitle(_("Audacity is starting up..."));
    SetTopWindow(temporarywindow);
 
-   // Initialize the ModuleManager
-   ModuleManager::Initialize();
-
    // Initialize the CommandHandler
    InitCommandHandler();
 
-   // load audacity plug-in modules
-   LoadModules(*mCmdHandler);
+   // Initialize the ModuleManager, including loading found modules
+   ModuleManager::Initialize(*mCmdHandler);
 
    // Locale
    // wxWidgets 2.3 has a much nicer wxLocale API.  We can make this code much
@@ -1156,18 +1205,6 @@ bool AudacityApp::OnInit()
    if (lang == wxT(""))
       lang = GetSystemLanguageCode();
 
-#ifdef CLEANSPEECH
-#ifdef NOT_RQD
-//TIDY-ME: (CleanSpeech) Language prompt??
-// The prompt for language only happens ONCE on a system.
-// I don't think we should disable it JKC
-   wxString lang = gPrefs->Read(wxT("/Locale/Language"), "en");  //lda
-
-// Pop up a dialog the first time the program is run
-//lda   if (lang == "")
-//lda      lang = ChooseLanguage(NULL);
-#endif
-#endif   // CLEANSPEECH
    mLocale = NULL;
    InitLang( lang );
 
@@ -1180,9 +1217,6 @@ bool AudacityApp::OnInit()
    }
 
    // More initialization
-#ifdef CLEANSPEECH
-   InitCleanSpeech();
-#endif   // CLEANSPEECH
 
    InitDitherers();
    InitAudioIO();
@@ -1447,56 +1481,6 @@ void AudacityApp::OnReceiveCommand(AppCommandEvent &event)
    mCmdHandler->OnReceiveCommand(event);
 }
 
-#ifdef CLEANSPEECH   //is this actually useful?
-bool AudacityApp::InitCleanSpeech()
-{
-   wxString userdatadir = FileNames::DataDir();
-   wxString presetsFromPrefs = gPrefs->Read(wxT("/Directories/PresetsDir"), wxT(""));
-   wxString presets = wxT("");
-
-   #ifdef __WXGTK__
-   if (presetsFromPrefs.Length() > 0 && presetsFromPrefs[0] != wxT('/'))
-      presetsFromPrefs = wxT("");
-   #endif //__WXGTK__
-
-   wxString presetsDefaultLoc =
-      wxFileName(userdatadir, wxT("presets")).GetFullPath();
-
-   // Stop wxWidgets from printing its own error messages (not used ... does this really do anything?)
-   wxLogNull logNo;
-   
-   // Try temp dir that was stored in prefs first
-   if (presetsFromPrefs != wxT("")) {
-      if (wxDirExists(presetsFromPrefs))
-         presets = presetsFromPrefs;
-      else if (wxMkdir(presetsFromPrefs))
-         presets = presetsFromPrefs;
-   }
-
-   // If that didn't work, try the default location
-   if ((presets == wxT("")) && (presetsDefaultLoc != wxT(""))) {
-      if (wxDirExists(presetsDefaultLoc))
-         presets = presetsDefaultLoc;
-      else if (wxMkdir(presetsDefaultLoc))
-         presets = presetsDefaultLoc;
-   }
-
-   if (presets == wxT("")) {
-      // Failed
-      wxMessageBox(wxT("Audacity could not find a place to store\n.csp CleanSpeech preset files\nAudacity is now going to exit. \nInstallation may be corrupt."));
-      return false;
-   }
-
-   // The permissions don't always seem to be set on
-   // some platforms.  Hopefully this fixes it...
-   #ifdef __UNIX__
-   chmod(OSFILENAME(presets), 0755);
-   #endif
-
-   return (gPrefs->Write(wxT("/Directories/PresetsDir"), presets) && gPrefs->Flush());
-}
-#endif   // CLEANSPEECH
-
 bool AudacityApp::InitTempDir()
 {
    // We need to find a temp directory location.
