@@ -38,7 +38,7 @@
 class AudioIO;
 class RingBuffer;
 class Mixer;
-class ConstRateResample;
+class Resample;
 class TimeTrack;
 class AudioThread;
 class Meter;
@@ -198,6 +198,15 @@ class AUDACITY_DLL_API AudioIO {
     * disable the UI if it doesn't work.
     */
    bool InputMixerWorks();
+
+   /** @brief Find out if the output level control is being emulated via software attenuation
+    *
+    * Checks the mEmulateMixerOutputVol variable, which is set up in
+    * AudioIO::HandleDeviceChange(). External classes care, because we want to
+    * modify the UI if it doesn't work.
+    */
+   bool OutputMixerEmulated();
+
    /** \brief Get the list of inputs to the current mixer device
     *
     * Returns an array of strings giving the names of the inputs to the 
@@ -474,7 +483,7 @@ private:
 #ifdef EXPERIMENTAL_MIDI_OUT
    AudioThread         *mMidiThread;
 #endif
-   ConstRateResample **mResample;
+   Resample          **mResample;
    RingBuffer        **mCaptureBuffers;
    WaveTrackArray      mCaptureTracks;
    RingBuffer        **mPlaybackBuffers;
