@@ -163,7 +163,7 @@ void Envelope::CopyFrom(const Envelope *e, double t0, double t1)
 
 /// Limit() limits a double value to a range.
 /// TODO: Move to a general utilities source file.
-double Limit( double Lo, double Value, double Hi )
+static double Limit( double Lo, double Value, double Hi )
 {
    if( Value < Lo )
       return Lo;
@@ -201,7 +201,7 @@ double Envelope::fromDB(double value) const
 }
 
 /// TODO: This should probably move to track artist.
-void DrawPoint(wxDC & dc, const wxRect & r, int x, int y, bool top)
+static void DrawPoint(wxDC & dc, const wxRect & r, int x, int y, bool top)
 {
    if (y >= 0 && y <= r.height) {
       wxRect circle(r.x + x, r.y + (top ? y - 1: y - 2), 4, 4);
@@ -518,7 +518,7 @@ void Envelope::MarkDragPointForDeletion()
 }
 
 void Envelope::MoveDraggedPoint( wxMouseEvent & event, wxRect & r,
-                               double h, double pps, bool dB,
+                               double WXUNUSED(h), double pps, bool dB,
                                float zoomMin, float zoomMax)
 {
    int clip_y = event.m_y - r.y;
@@ -555,7 +555,8 @@ void Envelope::MoveDraggedPoint( wxMouseEvent & event, wxRect & r,
 
 bool Envelope::HandleDragging( wxMouseEvent & event, wxRect & r,
                                double h, double pps, bool dB,
-                               float zoomMin, float zoomMax, float eMin, float eMax)
+                               float zoomMin, float zoomMax, 
+                               float WXUNUSED(eMin), float WXUNUSED(eMax))
 {
    mDirty = true;
 
@@ -580,9 +581,11 @@ bool Envelope::HandleDragging( wxMouseEvent & event, wxRect & r,
 }
 
 // Exit dragging mode and deletes dragged point if neccessary.
-bool Envelope::HandleMouseButtonUp( wxMouseEvent & event, wxRect & r,
-                                    double h, double pps, bool dB,
-                                    float zoomMin, float zoomMax )
+bool Envelope::HandleMouseButtonUp( wxMouseEvent & WXUNUSED(event), wxRect & WXUNUSED(r),
+                                    double WXUNUSED(h), 
+                                    double WXUNUSED(pps), bool WXUNUSED(dB),
+                                    float WXUNUSED(zoomMin), 
+                                    float WXUNUSED(zoomMax) )
 {
    if (mIsDeleting) {
       delete mEnv[mDragPoint];
@@ -1492,7 +1495,7 @@ void Envelope::print()
       printf( "(%.2f, %.2f)\n", mEnv[i]->GetT(), mEnv[i]->GetVal() );
 }
 
-void checkResult( int n, double a, double b )
+static void checkResult( int n, double a, double b )
 {
    if( (a-b > 0 ? a-b : b-a) > 0.0000001 )
    {
