@@ -336,10 +336,8 @@ bool LabelDialog::TransferDataFromWindow()
          return false;
 
       // Add the label to it
-      if (!rd->title.IsEmpty()) {
-         ((LabelTrack *) t)->AddLabel(rd->stime, rd->etime, rd->title);
-         ((LabelTrack *) t)->Unselect();
-      }
+      ((LabelTrack *) t)->AddLabel(rd->stime, rd->etime, rd->title);
+      ((LabelTrack *) t)->Unselect();
    }
 
    return true;
@@ -347,25 +345,11 @@ bool LabelDialog::TransferDataFromWindow()
 
 bool LabelDialog::Validate()
 {
-   int cnt = mData.GetCount();
-   int i;
-   
    if (mGrid->IsCellEditControlShown()) {
       mGrid->HideCellEditControl();
       mGrid->SaveEditControlValue();
    }
 
-   for (i = 0; i < cnt; i++) {
-      if (mData[i]->title.IsEmpty()) {
-         int id = wxMessageBox(_("You have left blank label names.  These will be\nskipped when repopulating the Label Tracks.\n\nWould you like to go back and provide names?"),
-                               _("Confirm"),
-                               wxYES_NO | wxICON_EXCLAMATION);
-         if (id == wxYES) {
-            return false;
-         }
-      }
-   }
-   
    return true;
 }
 
@@ -482,7 +466,7 @@ void LabelDialog::OnInsert(wxCommandEvent &event)
    mGrid->ShowCellEditControl();
 }
 
-void LabelDialog::OnRemove(wxCommandEvent &event)
+void LabelDialog::OnRemove(wxCommandEvent & WXUNUSED(event))
 {
    int row = mGrid->GetCursorRow();
    int col = mGrid->GetCursorColumn();
@@ -500,6 +484,7 @@ void LabelDialog::OnRemove(wxCommandEvent &event)
 
    // Remove the row
    RowData *rd = mData[row];
+   mTrackNames.RemoveAt(rd->index);
    mData.RemoveAt(row);
    delete rd;
 
@@ -511,9 +496,17 @@ void LabelDialog::OnRemove(wxCommandEvent &event)
       row--;
    }
    mGrid->SetGridCursor(row, col);
+
+   // Make sure focus isn't lost
+   if (mData.GetCount() == 0 && wxWindow::FindFocus() == mGrid->GetGridWindow()) {
+      wxWindow *ok = wxWindow::FindWindowById( wxID_OK, this);
+      if (ok) {
+         ok->SetFocus();
+      }
+   }
 }
 
-void LabelDialog::OnImport(wxCommandEvent &event)
+void LabelDialog::OnImport(wxCommandEvent & WXUNUSED(event))
 {
    wxString path = gPrefs->Read(wxT("/DefaultOpenPath"),::wxGetCwd());
 
@@ -558,7 +551,7 @@ void LabelDialog::OnImport(wxCommandEvent &event)
    }
 }
 
-void LabelDialog::OnExport(wxCommandEvent &event)
+void LabelDialog::OnExport(wxCommandEvent & WXUNUSED(event))
 {
    int cnt = mData.GetCount();
 
@@ -644,12 +637,15 @@ void LabelDialog::OnSelectCell(wxGridEvent &event)
       t = iter.Next();
    }
 
-   RowData *rd;
-   rd = mData[event.GetRow()];
-   mViewInfo->sel0 = rd->stime;
-   mViewInfo->sel1 = rd->etime;
+   if (!mData.empty())
+   {
+      RowData *rd;
+      rd = mData[event.GetRow()];
+      mViewInfo->sel0 = rd->stime;
+      mViewInfo->sel1 = rd->etime;
 
-   GetActiveProject()->RedrawProject();
+      GetActiveProject()->RedrawProject();
+   }
 
    event.Skip();
 }
@@ -698,7 +694,7 @@ void LabelDialog::OnCellChange(wxGridEvent &event)
    return;
 }
 
-void LabelDialog::OnChangeTrack(wxGridEvent &event, int row, RowData *rd)
+void LabelDialog::OnChangeTrack(wxGridEvent & WXUNUSED(event), int row, RowData *rd)
 {
    wxString val = mGrid->GetCellValue(row, Col_Track);
 
@@ -732,7 +728,7 @@ void LabelDialog::OnChangeTrack(wxGridEvent &event, int row, RowData *rd)
    return;
 }
 
-void LabelDialog::OnChangeLabel(wxGridEvent &event, int row, RowData *rd)
+void LabelDialog::OnChangeLabel(wxGridEvent & WXUNUSED(event), int row, RowData *rd)
 {
    // Remember the value...no need to repopulate
    rd->title = mGrid->GetCellValue(row, Col_Label);
@@ -740,7 +736,7 @@ void LabelDialog::OnChangeLabel(wxGridEvent &event, int row, RowData *rd)
    return;
 }
 
-void LabelDialog::OnChangeStime(wxGridEvent &event, int row, RowData *rd)
+void LabelDialog::OnChangeStime(wxGridEvent & WXUNUSED(event), int row, RowData *rd)
 {
    // Remember the value...no need to repopulate
    mGrid->GetCellValue(row, Col_Stime).ToDouble(&rd->stime);
@@ -752,7 +748,7 @@ void LabelDialog::OnChangeStime(wxGridEvent &event, int row, RowData *rd)
    return;
 }
 
-void LabelDialog::OnChangeEtime(wxGridEvent &event, int row, RowData *rd)
+void LabelDialog::OnChangeEtime(wxGridEvent & WXUNUSED(event), int row, RowData *rd)
 {
    // Remember the value...no need to repopulate
    mGrid->GetCellValue(row, Col_Etime).ToDouble(&rd->etime);
@@ -764,7 +760,7 @@ void LabelDialog::OnChangeEtime(wxGridEvent &event, int row, RowData *rd)
    return;
 }
 
-void LabelDialog::OnOK(wxCommandEvent &event)
+void LabelDialog::OnOK(wxCommandEvent & WXUNUSED(event))
 {
    if (mGrid->IsCellEditControlShown()) {
       mGrid->SaveEditControlValue();
@@ -780,7 +776,7 @@ void LabelDialog::OnOK(wxCommandEvent &event)
    return;
 }
 
-void LabelDialog::OnCancel(wxCommandEvent &event)
+void LabelDialog::OnCancel(wxCommandEvent & WXUNUSED(event))
 {
    if (mGrid->IsCellEditControlShown()) {
       mGrid->GetCellEditor(mGrid->GetGridCursorRow(),
