@@ -1236,7 +1236,7 @@ void LabelStruct::MoveLabel( int iEdge, double fNewTime)
 }
 
 LabelStruct::TimeRelations LabelStruct::RegionRelation(
-      double reg_t0, double reg_t1, LabelTrack *parent)
+      double reg_t0, double reg_t1, LabelTrack * WXUNUSED(parent))
 {
    bool retainLabels = false;
 
@@ -1345,7 +1345,7 @@ void LabelTrack::MayMoveLabel( int iLabel, int iEdge, double fNewTime)
 
 // Constrain function, as in processing/arduino.
 // returned value will be between min and max (inclusive).
-int Constrain( int value, int min, int max )
+static int Constrain( int value, int min, int max )
 {
    wxASSERT( min <= max );
    int result=value;
@@ -1834,16 +1834,32 @@ bool LabelTrack::OnKeyDown(double & newSel0, double & newSel1, wxKeyEvent & even
       case WXK_TAB:
       case WXK_NUMPAD_TAB:
          if (!mLabels.IsEmpty()) {
+            int len = (int) mLabels.Count();
             if (event.ShiftDown()) {
-               mSelIndex = (int)mLabels.Count() - 1;
+               mSelIndex = len - 1;
+               if (newSel0 > mLabels[0]->t) {
+                  while (mSelIndex >= 0 && mLabels[mSelIndex]->t >= newSel0) {
+                     mSelIndex--;
+                  }
+               }
             } else {
                mSelIndex = 0;
+               if (newSel0 < mLabels[len - 1]->t) {
+                  while (mSelIndex < len && mLabels[mSelIndex]->t <= newSel0) {
+                     mSelIndex++;
+                  }
+               }
+            }
+
+            if (mSelIndex >= 0 && mSelIndex < len) {
+               mCurrentCursorPos = mLabels[mSelIndex]->title.Length();
+               //Set the selection region to be equal to the selection bounds of the tabbed-to label.
+               newSel0 = mLabels[mSelIndex]->t;
+               newSel1 = mLabels[mSelIndex]->t1;
+            }
+            else {
+               mSelIndex = -1;
             }
-            
-            mCurrentCursorPos = mLabels[mSelIndex]->title.Length();
-            //Set the selection region to be equal to the selection bounds of the tabbed-to label.
-            newSel0 = mLabels[mSelIndex]->t;
-            newSel1 = mLabels[mSelIndex]->t1;
          }
          break;
 
@@ -1861,7 +1877,7 @@ bool LabelTrack::OnKeyDown(double & newSel0, double & newSel1, wxKeyEvent & even
 
 /// OnChar is called for incoming characters -- that's any keypress not handled
 /// by OnKeyDown.
-bool LabelTrack::OnChar(double & newSel0, double & newSel1, wxKeyEvent & event)
+bool LabelTrack::OnChar(double & WXUNUSED(newSel0), double & WXUNUSED(newSel1), wxKeyEvent & event)
 {
    // Only track true changes to the label
    bool updated = false;
@@ -2658,10 +2674,10 @@ void LabelTrack::CreateCustomGlyphs()
 /// Returns true for keys we capture to start a label.
 bool LabelTrack::IsGoodLabelFirstKey(int keyCode)
 {
-   // Allow everything before WXK_START except space and delete, the numpad keys
+   // Allow everything before WXK_START except space, return and delete, the numpad keys
    // when numlock is on, and everything after WXK_COMMAND
    return (keyCode < WXK_START
-                  && keyCode != WXK_SPACE && keyCode != WXK_DELETE) ||
+                  && keyCode != WXK_SPACE && keyCode != WXK_DELETE && keyCode != WXK_RETURN) ||
           (keyCode >= WXK_NUMPAD0 && keyCode <= WXK_DIVIDE) ||
           (keyCode >= WXK_NUMPAD_EQUAL && keyCode <= WXK_NUMPAD_DIVIDE) ||
           (keyCode > WXK_COMMAND);
@@ -2674,7 +2690,8 @@ bool LabelTrack::IsGoodLabelEditKey(int keyCode)
    // within that range that are usually printable, plus the ones we use for
    // keyboard navigation.
    return keyCode < WXK_START ||
-          (keyCode >= WXK_END && keyCode <= WXK_DOWN) ||
+          (keyCode >= WXK_END && keyCode < WXK_UP) ||
+          (keyCode == WXK_RIGHT) ||
           (keyCode >= WXK_NUMPAD0 && keyCode <= WXK_DIVIDE) ||
           (keyCode >= WXK_NUMPAD_SPACE && keyCode <= WXK_NUMPAD_ENTER) ||
           (keyCode >= WXK_NUMPAD_HOME && keyCode <= WXK_NUMPAD_END) ||
@@ -2750,15 +2767,3 @@ wxString LabelTrack::GetTextOfLabels(double t0, double t1)
 
    return retVal;
 }
-
-// Indentation settings for Vim and Emacs and unique identifier for Arch, a
-// version control system. Please do not modify past this point.
-//
-// Local Variables:
-// c-basic-offset: 3
-// indent-tabs-mode: nil
-// End:
-//
-// vim: et sts=3 sw=3
-// arch-tag: f321cf69-6f22-4a1b-a44b-b70d533227e3
-
