@@ -235,6 +235,7 @@ Mixer::Mixer(int numInputTracks, WaveTrack **inputTracks,
 {
    int i;
 
+   mHighQuality = highQuality;
    mNumInputTracks = numInputTracks;
    mInputTrack = new WaveTrack*[mNumInputTracks];
    mSamplePos = new sampleCount[mNumInputTracks];
@@ -286,11 +287,12 @@ Mixer::Mixer(int numInputTracks, WaveTrack **inputTracks,
    for(i=0; i<mNumInputTracks; i++) {
       double factor = (mRate / mInputTrack[i]->GetRate());
       if (timeTrack) {
-         mResample[i] = new VarRateResample(highQuality,
-                                            factor / timeTrack->GetRangeUpper(),
-                                            factor / timeTrack->GetRangeLower());
+         // variable rate resampling
+         mResample[i] = new Resample(mHighQuality,
+                                      factor / timeTrack->GetRangeUpper(),
+                                      factor / timeTrack->GetRangeLower());
       } else {
-         mResample[i] = new ConstRateResample(highQuality, factor);
+         mResample[i] = new Resample(mHighQuality, factor, factor); // constant rate resampling
       }
       mSampleQueue[i] = new float[mQueueMaxLen];
       mQueueStart[i] = 0;
@@ -317,13 +319,13 @@ Mixer::~Mixer()
    delete[] mEnvValues;
    delete[] mFloatBuffer;
    delete[] mGains;
-	delete[] mSamplePos;
+   delete[] mSamplePos;
 
    for(i=0; i<mNumInputTracks; i++) {
       delete mResample[i];
       delete[] mSampleQueue[i];
    }
-	delete[] mResample;
+   delete[] mResample;
    delete[] mSampleQueue;
    delete[] mQueueStart;
    delete[] mQueueLen;
@@ -594,10 +596,28 @@ sampleCount Mixer::Process(sampleCount maxToProcess)
          mTime = std::min(t, mT1);
       
    }
-   out = mInterleaved ? maxOut * mNumChannels : maxOut;
-   for(int c=0; c<mNumBuffers; c++)
-      CopySamples(mTemp[c], floatSample, mBuffer[c], mFormat, out);
-
+   if(mInterleaved) {
+      for(int c=0; c<mNumChannels; c++) {
+         CopySamples(mTemp[0] + (c * SAMPLE_SIZE(floatSample)),
+                     floatSample,
+                     mBuffer[0] + (c * SAMPLE_SIZE(mFormat)),
+                     mFormat,
+                     maxOut,
+                     mHighQuality,
+                     mNumChannels,
+                     mNumChannels);
+      }
+   }
+   else {
+      for(int c=0; c<mNumBuffers; c++) {
+            CopySamples(mTemp[c],
+                        floatSample,
+                        mBuffer[c],
+                        mFormat,
+                        maxOut,
+                        mHighQuality);
+      }
+   }
    // MB: this doesn't take warping into account, replaced with code based on mSamplePos
    //mT += (maxOut / mRate);
 
