@@ -793,7 +793,7 @@ bool NoteTrack::HandleXMLTag(const wxChar *tag, const wxChar **attrs)
    return false;
 }
 
-XMLTagHandler *NoteTrack::HandleXMLChild(const wxChar *tag)
+XMLTagHandler *NoteTrack::HandleXMLChild(const wxChar * WXUNUSED(tag))
 {
    return NULL;
 }
@@ -904,15 +904,3 @@ int NoteTrack::YToIPitch(int y)
 }
 
 #endif // USE_MIDI
-
-// Indentation settings for Vim and Emacs and unique identifier for Arch, a
-// version control system. Please do not modify past this point.
-//
-// Local Variables:
-// c-basic-offset: 3
-// indent-tabs-mode: nil
-// End:
-//
-// vim: et sts=3 sw=3
-// arch-tag: ecfdee12-5b16-4f27-84d1-4a3800d07d1e
-
