@@ -57,6 +57,7 @@ to get its definition, rather than rolling our own.
 
 *//*******************************************************************/
 
+#include <wx/wx.h>
 #include <wx/filefn.h>
 #include <wx/ffile.h>
 #include <wx/utils.h>
@@ -71,7 +72,7 @@ to get its definition, rather than rolling our own.
 #include "../Internat.h"
 
 
-wxUint32 SwapUintEndianess(wxUint32 in)
+static wxUint32 SwapUintEndianess(wxUint32 in)
 {
   wxUint32 out;
   unsigned char *p_in = (unsigned char *) &in;
@@ -609,16 +610,3 @@ bool SimpleBlockFile::GetCache()
    return false;
 #endif
 }
-
-// Indentation settings for Vim and Emacs and unique identifier for Arch, a
-// version control system. Please do not modify past this point.
-//
-// Local Variables:
-// c-basic-offset: 3
-// indent-tabs-mode: nil
-// End:
-//
-// vim: et sts=3 sw=3
-// arch-tag: 606f2b69-1fda-40a3-88e6-06ff91d708c2
-
-
