@@ -32,6 +32,9 @@
 #include <wx/stattext.h>
 #include <wx/stopwatch.h>
 #include <wx/utils.h>
+#include <wx/dcclient.h>
+#include <wx/imaglist.h>
+#include <wx/listctrl.h>
 
 #if defined(__WXMAC__)
 #include <dlfcn.h>
@@ -57,6 +60,8 @@
 #include "../../xml/XMLFileReader.h"
 #include "../../xml/XMLWriter.h"
 #include "../EffectManager.h"
+#include "../../Theme.h"
+#include "../images/Arrow.xpm"
 
 #include "VSTEffect.h"
 
@@ -72,15 +77,20 @@ void RegisterVSTEffects()
 
    pm.Open();
 
-   if (gPrefs->Read(wxT("/VST/Rescan"), (long) false) != false) {
+   bool bRescanRequired=false;
+   if ( gPrefs->Read(wxT("/VST/Rescan"), (long)true) != false) {
+      bRescanRequired = true;
       pm.PurgeType(VSTPLUGINTYPE);
-      gPrefs->Write(wxT("/VST/Rescan"), false);
-      gPrefs->Flush();
    }
 
    if (!pm.HasType(VSTPLUGINTYPE)) {
       pm.Close();
-      VSTEffect::Scan();
+      if( bRescanRequired )
+         if( VSTEffect::Scan() != wxID_CANCEL ) 
+         {
+            gPrefs->Write(wxT("/VST/Rescan"), false);
+            gPrefs->Flush();
+         }
       pm.Open();
    }
 
@@ -102,6 +112,578 @@ void RegisterVSTEffects()
    pm.Close();
 }
 
+#if wxUSE_ACCESSIBILITY
+
+class CheckListAx: public wxWindowAccessible
+{
+ public:
+   CheckListAx(wxListCtrl * window);
+
+   virtual ~ CheckListAx();
+
+   // Retrieves the address of an IDispatch interface for the specified child.
+   // All objects must support this property.
+   virtual wxAccStatus GetChild( int childId, wxAccessible **child );
+
+   // Gets the number of children.
+   virtual wxAccStatus GetChildCount( int *childCount );
+
+   // Gets the default action for this object (0) or > 0 (the action for a child).
+   // Return wxACC_OK even if there is no action. actionName is the action, or the empty
+   // string if there is no action.
+   // The retrieved string describes the action that is performed on an object,
+   // not what the object does as a result. For example, a toolbar button that prints
+   // a document has a default action of "Press" rather than "Prints the current document."
+   virtual wxAccStatus GetDefaultAction( int childId, wxString *actionName );
+
+   // Returns the description for this object or a child.
+   virtual wxAccStatus GetDescription( int childId, wxString *description );
+
+   // Gets the window with the keyboard focus.
+   // If childId is 0 and child is NULL, no object in
+   // this subhierarchy has the focus.
+   // If this object has the focus, child should be 'this'.
+   virtual wxAccStatus GetFocus( int *childId, wxAccessible **child );
+
+   // Returns help text for this object or a child, similar to tooltip text.
+   virtual wxAccStatus GetHelpText( int childId, wxString *helpText );
+
+   // Returns the keyboard shortcut for this object or child.
+   // Return e.g. ALT+K
+   virtual wxAccStatus GetKeyboardShortcut( int childId, wxString *shortcut );
+
+   // Returns the rectangle for this object (id = 0) or a child element (id > 0).
+   // rect is in screen coordinates.
+   virtual wxAccStatus GetLocation( wxRect& rect, int elementId );
+
+   // Gets the name of the specified object.
+   virtual wxAccStatus GetName( int childId, wxString *name );
+
+   // Returns a role constant.
+   virtual wxAccStatus GetRole( int childId, wxAccRole *role );
+
+   // Gets a variant representing the selected children
+   // of this object.
+   // Acceptable values:
+   // - a null variant (IsNull() returns TRUE)
+   // - a list variant (GetType() == wxT("list"))
+   // - an integer representing the selected child element,
+   //   or 0 if this object is selected (GetType() == wxT("long"))
+   // - a "void*" pointer to a wxAccessible child object
+   virtual wxAccStatus GetSelections( wxVariant *selections );
+
+   // Returns a state constant.
+   virtual wxAccStatus GetState( int childId, long* state );
+
+   // Returns a localized string representing the value for the object
+   // or child.
+   virtual wxAccStatus GetValue( int childId, wxString *strValue );
+
+   void SetSelected( int item );
+ private:
+   wxListCtrl *mParent;
+   int mLastId;
+};
+
+CheckListAx::CheckListAx( wxListCtrl * window ):
+   wxWindowAccessible( window )
+{
+   mParent = window;
+   mLastId = -1;
+}
+
+CheckListAx::~CheckListAx()
+{
+}
+
+void CheckListAx::SetSelected( int item )
+{
+#if 0
+   NotifyEvent(wxACC_EVENT_OBJECT_REORDER,
+               mParent,
+               wxOBJID_CLIENT,
+               0);
+#endif
+#if 1
+   if (mLastId != -1) {
+      NotifyEvent(wxACC_EVENT_OBJECT_SELECTIONREMOVE,
+               mParent,
+               wxOBJID_CLIENT,
+               mLastId);
+      mLastId = -1;
+   }
+
+   if (item != -1)
+   {
+      NotifyEvent(wxACC_EVENT_OBJECT_FOCUS,
+                  mParent,
+                  wxOBJID_CLIENT,
+                  item + 1);
+
+      NotifyEvent(wxACC_EVENT_OBJECT_SELECTION,
+                  mParent,
+                  wxOBJID_CLIENT,
+                  item + 1);
+
+      mLastId = item + 1;
+   }
+#endif
+}
+
+// Retrieves the address of an IDispatch interface for the specified child.
+// All objects must support this property.
+wxAccStatus CheckListAx::GetChild( int childId, wxAccessible** child )
+{
+   if( childId == wxACC_SELF )
+   {
+      *child = this;
+   }
+   else
+   {
+      *child = NULL;
+   }
+
+   return wxACC_OK;
+}
+
+// Gets the number of children.
+wxAccStatus CheckListAx::GetChildCount( int *childCount )
+{
+   *childCount = mParent->GetItemCount();
+
+   return wxACC_OK;
+}
+
+// Gets the default action for this object (0) or > 0 (the action for a child).
+// Return wxACC_OK even if there is no action. actionName is the action, or the empty
+// string if there is no action.
+// The retrieved string describes the action that is performed on an object,
+// not what the object does as a result. For example, a toolbar button that prints
+// a document has a default action of "Press" rather than "Prints the current document."
+wxAccStatus CheckListAx::GetDefaultAction( int WXUNUSED(childId), wxString *actionName )
+{
+   actionName->Clear();
+
+   return wxACC_OK;
+}
+
+// Returns the description for this object or a child.
+wxAccStatus CheckListAx::GetDescription( int WXUNUSED(childId), wxString *description )
+{
+   description->Clear();
+
+   return wxACC_OK;
+}
+
+// Gets the window with the keyboard focus.
+// If childId is 0 and child is NULL, no object in
+// this subhierarchy has the focus.
+// If this object has the focus, child should be 'this'.
+wxAccStatus CheckListAx::GetFocus( int *childId, wxAccessible **child )
+{
+   *childId = 0;
+   *child = this;
+
+   return wxACC_OK;
+}
+
+// Returns help text for this object or a child, similar to tooltip text.
+wxAccStatus CheckListAx::GetHelpText( int WXUNUSED(childId), wxString *helpText )
+{
+   helpText->Clear();
+
+   return wxACC_OK;
+}
+
+// Returns the keyboard shortcut for this object or child.
+// Return e.g. ALT+K
+wxAccStatus CheckListAx::GetKeyboardShortcut( int WXUNUSED(childId), wxString *shortcut )
+{
+   shortcut->Clear();
+
+   return wxACC_OK;
+}
+
+// Returns the rectangle for this object (id = 0) or a child element (id > 0).
+// rect is in screen coordinates.
+wxAccStatus CheckListAx::GetLocation( wxRect& rect, int elementId )
+{
+   if( elementId == wxACC_SELF )
+   {
+      rect = mParent->GetRect();
+      rect.SetPosition( mParent->GetParent()->ClientToScreen( rect.GetPosition() ) );
+   }
+   else
+   {
+      if( elementId <= mParent->GetItemCount() )
+      {
+         mParent->GetItemRect( elementId - 1, rect, wxLIST_RECT_LABEL );
+         rect.SetPosition( mParent->ClientToScreen( rect.GetPosition() ) );
+      }
+   }
+
+   return wxACC_OK;
+}
+
+// Gets the name of the specified object.
+wxAccStatus CheckListAx::GetName( int WXUNUSED(childId), wxString *name )
+{
+   *name = mParent->GetName();
+
+   return wxACC_OK;
+}
+
+// Returns a role constant.
+wxAccStatus CheckListAx::GetRole( int childId, wxAccRole *role )
+{
+   if( childId == wxACC_SELF )
+   {
+      *role = wxROLE_SYSTEM_LIST;
+   }
+   else
+   {
+      *role = wxROLE_SYSTEM_LISTITEM;
+   }
+
+   return wxACC_OK;
+}
+
+// Gets a variant representing the selected children
+// of this object.
+// Acceptable values:
+// - a null variant (IsNull() returns TRUE)
+// - a list variant (GetType() == wxT("list"))
+// - an integer representing the selected child element,
+//   or 0 if this object is selected (GetType() == wxT("long"))
+// - a "void*" pointer to a wxAccessible child object
+wxAccStatus CheckListAx::GetSelections( wxVariant * WXUNUSED(selections) )
+{
+   return wxACC_NOT_IMPLEMENTED;
+}
+
+// Returns a state constant.
+wxAccStatus CheckListAx::GetState( int childId, long *state )
+{
+   int flag = wxACC_STATE_SYSTEM_FOCUSABLE;
+
+   if( childId == wxACC_SELF )
+   {
+      flag |= wxACC_STATE_SYSTEM_FOCUSED;
+   }
+   else
+   {
+      wxListItem item;
+
+      item.SetId( childId - 1 );
+      item.SetState( wxLIST_STATE_FOCUSED | wxLIST_STATE_SELECTED );
+      item.SetMask( wxLIST_MASK_IMAGE | wxLIST_MASK_STATE );
+
+      if( mParent->GetItem( item ) )
+      {
+         flag |= wxACC_STATE_SYSTEM_SELECTABLE;
+
+         long state = item.GetState();
+
+         if( state & wxLIST_STATE_FOCUSED )
+         {
+            flag |= wxACC_STATE_SYSTEM_FOCUSED;
+         }
+
+         if( state & wxLIST_STATE_SELECTED )
+         {
+            flag |= wxACC_STATE_SYSTEM_SELECTED;
+         }
+
+         if( item.GetImage() != 0 )
+         {
+            flag |= wxACC_STATE_SYSTEM_CHECKED;
+         }
+      }
+   }
+
+   *state = flag;
+
+   return wxACC_OK;
+}
+
+// Returns a localized string representing the value for the object
+// or child.
+wxAccStatus CheckListAx::GetValue( int childId, wxString *strValue )
+{
+   if( childId == 0 )
+   {
+      return wxACC_OK;
+   }
+   else
+   {
+      *strValue = mParent->GetItemText( childId - 1 );
+   }
+
+   return wxACC_OK;
+}
+
+#endif
+
+class PluginRegistrationDialog:public wxDialog {
+ public:
+   // constructors and destructors
+   PluginRegistrationDialog(wxWindow * parent, const wxArrayString & files);
+   virtual ~PluginRegistrationDialog();
+ public:
+   void Populate();
+   void PopulateOrExchange( ShuttleGui & S );
+
+   void OnApply(wxCommandEvent & event);
+   void OnCancel(wxCommandEvent & event);
+   void OnListChar( wxKeyEvent & event );
+   void OnListMouseDown( wxMouseEvent & event );
+
+   void SetBoldOrRegular( int i );
+   void ToggleItem(int i);
+
+#if wxUSE_ACCESSIBILITY
+   CheckListAx *mAx;
+#endif
+   wxButton *mOK;
+   wxButton *mCancel;
+   wxListCtrl *mPlugins;
+   wxArrayString mFiles;
+   wxArrayInt miState;
+
+   DECLARE_EVENT_TABLE()
+};
+
+
+#define PluginListID       7001
+
+BEGIN_EVENT_TABLE(PluginRegistrationDialog, wxDialog)
+   EVT_BUTTON(wxID_OK, PluginRegistrationDialog::OnApply)
+   EVT_BUTTON(wxID_CANCEL, PluginRegistrationDialog::OnCancel)
+END_EVENT_TABLE()
+
+PluginRegistrationDialog::PluginRegistrationDialog(wxWindow * parent, const wxArrayString & files):
+   mFiles( files ),
+   wxDialog(parent, wxID_ANY, _("Install VST Effects"),
+            wxDefaultPosition, wxDefaultSize,
+            wxDEFAULT_DIALOG_STYLE | wxRESIZE_BORDER)
+{
+   mPlugins = NULL;
+   SetLabel(_("Install VST Effects"));         // Provide visual label
+   SetName(_("Install VST Effects"));          // Provide audible label
+   Populate();
+   SetReturnCode( wxID_OK);
+}
+
+PluginRegistrationDialog::~PluginRegistrationDialog()
+{
+   mPlugins->Disconnect(wxEVT_LEFT_DOWN,
+                        wxMouseEventHandler(PluginRegistrationDialog::OnListMouseDown),
+                        NULL,
+                        this);
+   mPlugins->Disconnect(wxEVT_KEY_DOWN,
+                        wxKeyEventHandler(PluginRegistrationDialog::OnListChar),
+                        NULL,
+                        this);
+}
+
+void PluginRegistrationDialog::Populate()
+{
+   //------------------------- Main section --------------------
+   ShuttleGui S(this, eIsCreating);
+   PopulateOrExchange(S);
+   // ----------------------- End of main section --------------
+}
+
+/// Defines the dialog and does data exchange with it.
+void PluginRegistrationDialog::PopulateOrExchange(ShuttleGui &S)
+{
+   wxImageList * pImageList = new wxImageList( 16, 16 );
+
+#define SHOW_UNCHECKED (0)
+#define SHOW_CHECKED (1)
+#define SHOW_ARROW (2)
+
+#define COL_NAME (0)
+#define COL_PATH (1)
+
+   pImageList->Add(wxIcon(unchecked_xpm));
+   pImageList->Add(wxIcon(checked_xpm));
+   pImageList->Add(wxIcon(arrow15x15_xpm));
+
+   S.StartVerticalLay(true);
+   {
+      /*i18n-hint: The dialog shows a list of plugins with check-boxes 
+       beside each one.*/
+      S.StartStatic(_("&Select Plug-ins to Install or press ENTER to Install All"), true);
+      {
+         S.SetStyle(wxSUNKEN_BORDER | wxLC_REPORT | wxLC_SINGLE_SEL | wxLC_HRULES | wxLC_VRULES );
+         mPlugins = S.Id(PluginListID).AddListControlReportMode();
+         mPlugins->Connect(wxEVT_LEFT_DOWN,
+                           wxMouseEventHandler(PluginRegistrationDialog::OnListMouseDown),
+                           NULL,
+                           this);
+         mPlugins->Connect(wxEVT_KEY_DOWN,
+                           wxKeyEventHandler(PluginRegistrationDialog::OnListChar),
+                           NULL,
+                           this);
+#if wxUSE_ACCESSIBILITY
+         mAx = new CheckListAx(mPlugins);
+         mPlugins->SetAccessible(mAx);
+#endif
+         mPlugins->AssignImageList( pImageList, wxIMAGE_LIST_SMALL );
+         mPlugins->InsertColumn(COL_NAME, _("Plug-in Name"));
+         mPlugins->InsertColumn(COL_PATH, _("Path"));
+      }
+      S.EndStatic();
+
+      S.StartHorizontalLay(wxALIGN_RIGHT, false);
+      {
+         S.SetBorder(10);
+         S.Id(wxID_CANCEL).AddButton(_("&Cancel"));
+         S.Id(wxID_OK).AddButton(_("OK"))->SetDefault();
+      }
+      S.EndHorizontalLay();
+   }
+   S.EndVerticalLay();
+
+   // The dc is used to compute the text width in pixels.
+   // FIXME: That works fine for PC, but apparently comes out too small for wxMAC.
+   // iLen is minimum width in pixels shown for the file names.  200 is reasonable.
+   int iNameLen = 0;
+   int iPathLen = 0;
+   int x, y;
+   for (int i = 0; i < (int)mFiles.GetCount(); i++)
+   {
+      miState.Add( SHOW_CHECKED );
+
+      wxFileName fn(mFiles[i]);
+      wxString name( fn.GetName() );
+      wxString path( fn.GetFullPath() );
+
+      mPlugins->InsertItem( i, name, SHOW_CHECKED );
+      mPlugins->SetItem( i, COL_PATH, path );
+
+      wxRect r;
+      mPlugins->GetItemRect( i, r, wxLIST_RECT_ICON );
+      mPlugins->GetTextExtent( name, &x, &y );
+      iNameLen = wxMax( iNameLen, x + r.width + (r.x * 2) );
+      mPlugins->GetTextExtent( path, &x, &y );
+      iPathLen = wxMax( iPathLen, x + r.width + (r.x * 2) );
+   }
+
+   mPlugins->SetColumnWidth(COL_NAME, iNameLen + /* fudge */ 5);
+   mPlugins->SetColumnWidth(COL_PATH, iPathLen + /* fudge */ 5);
+
+   //SetBoldOrRegular( miSelected );
+   mPlugins->SetSizeHints( iNameLen + iPathLen + /* fudge */ 15 , 200 );
+   if( mFiles.GetCount() > 0 )
+   {
+      // Make sure first item is selected/focused.
+      mPlugins->SetFocus();
+      mPlugins->SetItemState( 0, wxLIST_STATE_FOCUSED|wxLIST_STATE_SELECTED, wxLIST_STATE_FOCUSED|wxLIST_STATE_SELECTED);
+#if wxUSE_ACCESSIBILITY
+      mAx->SetSelected( 0 );
+#endif
+   }
+   Layout();
+   Fit();
+   SetSizeHints(GetSize());
+   // Parent window is usually not there yet, so centre on screen rather than on parent.
+   CenterOnScreen();
+
+}
+
+void PluginRegistrationDialog::OnListMouseDown( wxMouseEvent & event )
+{
+   wxPoint p = event.GetPosition();
+   int flags = wxLIST_HITTEST_ONITEM;
+   int item = mPlugins->HitTest( p, flags );
+
+   if( item != wxNOT_FOUND )
+   {
+      ToggleItem( item );
+   }
+
+   event.Skip();
+}
+
+void PluginRegistrationDialog::OnListChar( wxKeyEvent & event )
+{
+   switch( event.GetKeyCode() )
+   {
+      case WXK_SPACE:
+      {
+         int iItem = mPlugins->GetNextItem( -1, wxLIST_NEXT_ALL, wxLIST_STATE_FOCUSED);
+
+         if( iItem != wxNOT_FOUND )
+         {
+            ToggleItem( iItem );
+         }
+      }
+      break;
+
+      case WXK_RETURN:
+         // Don't know why wxListCtrls prevent default dialog action,
+         // but they do, so handle it.
+         EmulateButtonClickIfPresent( GetAffirmativeId() );
+      break;
+
+      default:
+         event.Skip();
+      break;
+   }
+}
+
+void PluginRegistrationDialog::SetBoldOrRegular( int i )
+{
+   wxFont Font = mPlugins->GetItemFont( i );
+   Font.SetWeight( (miState[i]==SHOW_CHECKED)? wxFONTWEIGHT_BOLD : wxFONTWEIGHT_NORMAL );
+   mPlugins->SetItemFont( i, Font );
+}
+
+// We can't capture mouse clicks, only selected and deselected.
+// Clicking on a selected item does not generate any event.
+// Therefore our workaround solution is to NEVER actually select.
+// So whenever the code tries to , we cancel the selection.
+// That way we continue to get events.
+void PluginRegistrationDialog::ToggleItem(int i)
+{
+   miState[ i ] = (miState[ i ]==SHOW_CHECKED) ? SHOW_UNCHECKED : SHOW_CHECKED; // Toggle it.
+   mPlugins->SetItemImage( i, miState[i] );
+#if wxUSE_ACCESSIBILITY
+   mAx->SetSelected( i );
+#endif
+
+   // SetBoldOrRegular( i );
+}
+
+void PluginRegistrationDialog::OnApply(wxCommandEvent & WXUNUSED(event))
+{
+
+   size_t cnt = mFiles.GetCount();
+   for (size_t i = 0; i < cnt; i++) {
+      wxString file = mFiles[i];
+
+      mPlugins->EnsureVisible( i );
+      if( miState[ i ] == SHOW_CHECKED )
+      {
+         mPlugins->SetItemImage( i, SHOW_ARROW );
+         VSTEffect::ScanOnePlugin( file );
+         mPlugins->SetItemImage( i, SHOW_CHECKED );
+      }
+   }
+   EndModal(wxID_OK);
+}
+
+void PluginRegistrationDialog::OnCancel(wxCommandEvent & WXUNUSED(event))
+{
+   EndModal(wxID_CANCEL);
+}
+
+
+
+
+
 ///////////////////////////////////////////////////////////////////////////////
 //
 // VSTEffectDialog
@@ -538,7 +1120,7 @@ void VSTEffectDialog::RefreshParameters(int skip)
    }
 }
 
-void VSTEffectDialog::OnIdle(wxIdleEvent & evt)
+void VSTEffectDialog::OnIdle(wxIdleEvent & WXUNUSED(event))
 {
    if (mGui) {
       mEffect->callDispatcher(effEditIdle, 0, 0, NULL, 0.0);
@@ -561,7 +1143,7 @@ void VSTEffectDialog::OnProgram(wxCommandEvent & evt)
    RefreshParameters();
 }
 
-void VSTEffectDialog::OnProgramText(wxCommandEvent & evt)
+void VSTEffectDialog::OnProgramText(wxCommandEvent & WXUNUSED(event))
 {
    wxString name = mProgram->GetValue();
    int i = mEffect->callDispatcher(effGetProgram, 0, 0, NULL, 0.0);
@@ -587,7 +1169,7 @@ void VSTEffectDialog::OnProgramText(wxCommandEvent & evt)
    RefreshParameters();
 }
 
-void VSTEffectDialog::OnLoad(wxCommandEvent & evt)
+void VSTEffectDialog::OnLoad(wxCommandEvent & WXUNUSED(event))
 {
    wxString fn;
 
@@ -620,7 +1202,7 @@ void VSTEffectDialog::OnLoad(wxCommandEvent & evt)
    return;
 }
 
-void VSTEffectDialog::OnSave(wxCommandEvent & evt)
+void VSTEffectDialog::OnSave(wxCommandEvent & WXUNUSED(event))
 {
    int i = mProgram->GetCurrentSelection();
    wxString fn;
@@ -692,17 +1274,17 @@ void VSTEffectDialog::OnSave(wxCommandEvent & evt)
    xmlFile.Close();
 }
 
-void VSTEffectDialog::OnClose(wxCloseEvent & evt)
+void VSTEffectDialog::OnClose(wxCloseEvent & WXUNUSED(event))
 {
    EndModal(false);
 }
 
-void VSTEffectDialog::OnPreview(wxCommandEvent & evt)
+void VSTEffectDialog::OnPreview(wxCommandEvent & WXUNUSED(event))
 {
    mEffect->Preview();
 }
 
-void VSTEffectDialog::OnOk(wxCommandEvent & evt)
+void VSTEffectDialog::OnOk(wxCommandEvent & WXUNUSED(event))
 {
    if (mGui) {
       mEffect->callDispatcher(effEditClose, 0, 0, NULL, 0.0);
@@ -711,7 +1293,7 @@ void VSTEffectDialog::OnOk(wxCommandEvent & evt)
    EndModal(true);
 }
 
-void VSTEffectDialog::OnCancel(wxCommandEvent & evt)
+void VSTEffectDialog::OnCancel(wxCommandEvent & WXUNUSED(event))
 {
    if (mGui) {
       mEffect->callDispatcher(effEditClose, 0, 0, NULL, 0.0);
@@ -949,19 +1531,19 @@ wxString VSTEffectDialog::b64encode(const void *in, int len)
    unsigned char *p = (unsigned char *) in;
    wxString out;
    
-	unsigned long temp;
-	for (int i = 0; i < len / 3; i++) {
-		temp  = (*p++) << 16; //Convert to big endian
-		temp += (*p++) << 8;
-		temp += (*p++);
-		out += cset[(temp & 0x00FC0000) >> 18];
-		out += cset[(temp & 0x0003F000) >> 12];
-		out += cset[(temp & 0x00000FC0) >> 6];
-		out += cset[(temp & 0x0000003F)];
-	}
+   unsigned long temp;
+   for (int i = 0; i < len / 3; i++) {
+      temp  = (*p++) << 16; //Convert to big endian
+      temp += (*p++) << 8;
+      temp += (*p++);
+      out += cset[(temp & 0x00FC0000) >> 18];
+      out += cset[(temp & 0x0003F000) >> 12];
+      out += cset[(temp & 0x00000FC0) >> 6];
+      out += cset[(temp & 0x0000003F)];
+   }
 
-	switch (len % 3)
-	{
+   switch (len % 3)
+   {
       case 1:
          temp  = (*p++) << 16; //Convert to big endian
          out += cset[(temp & 0x00FC0000) >> 18];
@@ -978,9 +1560,9 @@ wxString VSTEffectDialog::b64encode(const void *in, int len)
          out += cset[(temp & 0x00000FC0) >> 6];
          out += padc;
          break;
-	}
+   }
 
-	return out;
+   return out;
 }
 
 int VSTEffectDialog::b64decode(wxString in, void *out)
@@ -988,8 +1570,8 @@ int VSTEffectDialog::b64decode(wxString in, void *out)
    int len = in.Length();
    unsigned char *p = (unsigned char *) out;
 
-	if (len % 4) { //Sanity check
-		return 0;
+   if (len % 4) { //Sanity check
+      return 0;
    }
 
    int padding = 0;
@@ -1003,8 +1585,8 @@ int VSTEffectDialog::b64decode(wxString in, void *out)
       }
    }
 
-   const char *a = in.mb_str();
-	//Setup a vector to hold the result
+   //const char *a = in.mb_str();
+   //Setup a vector to hold the result
    unsigned long temp = 0; //Holds decoded quanta
    int i = 0;
    while (i < len) {
@@ -1040,7 +1622,7 @@ int VSTEffectDialog::b64decode(wxString in, void *out)
             }
          }
          i++;
-		}
+      }
       *p++ = (temp >> 16) & 0x000000FF;
       *p++ = (temp >> 8) & 0x000000FF;
       *p++ = temp & 0x000000FF;
@@ -1387,7 +1969,7 @@ bool VSTEffect::ProcessStereo(int count,
                               sampleCount len)
 {
    bool rc = true;
-   sampleCount amountLeft = 0;
+   //sampleCount amountLeft = 0;
 
    // Initialize time info
    mTimeInfo.samplePos = 0.0;
@@ -1674,8 +2256,49 @@ void VSTEffect::Unload()
    }
 }
 
+void VSTEffect::ScanOnePlugin( const wxString & file )
+{
+   const wxChar * argv[4];
+   argv[0] = PlatformCompatibility::GetExecutablePath().c_str();
+   argv[1] = VSTCMDKEY;
+   argv[2] = file.c_str();
+   argv[3] = NULL;
+   // ToDo: do we need a try--catch around this in case a bad plug-in 
+   // fails? (JKC Nov09)
+   wxExecute((wxChar **) argv, wxEXEC_SYNC | wxEXEC_NODISABLE, NULL);
+}
+
+int VSTEffect::ShowPluginListDialog( const wxArrayString & files )
+{
+   PluginRegistrationDialog d( wxGetApp().GetTopWindow(), files );
+   return d.ShowModal();
+}
+
+void VSTEffect::ShowProgressDialog( const wxString & longest, const wxArrayString & files )
+{
+   ProgressDialog *progress = new ProgressDialog(_("Scanning VST Plugins"),
+                                                 longest,
+                                                 pdlgHideStopButton);
+//   progress->SetSize(wxSize(500, -1));
+   progress->CenterOnScreen();
+
+   size_t cnt = files.GetCount();
+   for (size_t i = 0; i < cnt; i++) {
+      wxString file = files[i];
+      int status = progress->Update(wxLongLong(i),
+                                    wxLongLong(cnt),
+                                    wxString::Format(_("Checking %s"), file.c_str()));
+      if (status != eProgressSuccess) {
+         break;
+      }
+      ScanOnePlugin( file );
+   }
+
+   delete progress;   
+}
+
 /* static */
-void VSTEffect::Scan()
+int VSTEffect::Scan()
 {
    wxArrayString audacityPathList = wxGetApp().audacityPathList;
    wxArrayString pathList;
@@ -1769,6 +2392,8 @@ void VSTEffect::Scan()
 
 #endif
 
+   files.Sort();
+
    // This is a hack to allow for long paths in the progress dialog.  The
    // progress dialog should really truncate the message if it's too wide
    // for the dialog.
@@ -1778,42 +2403,17 @@ void VSTEffect::Scan()
    // JKC: Let's not show the progress dialog if there are no 
    // files to test.
    if( cnt <= 0 )
-      return;
+      return wxID_OK;
 
    for (size_t i = 0; i < cnt; i++) {
       if (files[i].Length() > longest.Length()) {
          longest = files[i];
       }
    }
-
-   ProgressDialog *progress = new ProgressDialog(_("Scanning VST Plugins"),
-                                                 longest,
-                                                 pdlgHideStopButton);
-//   progress->SetSize(wxSize(500, -1));
-   progress->CenterOnScreen();
-
-   const wxChar * argv[4];
-   argv[0] = PlatformCompatibility::GetExecutablePath().c_str();
-   argv[1] = VSTCMDKEY;
-   argv[2] = NULL;
-   argv[3] = NULL;
-
-   for (size_t i = 0; i < cnt; i++) {
-      wxString file = files[i];
-      int status = progress->Update(wxLongLong(i),
-                                    wxLongLong(cnt),
-                                    wxString::Format(_("Checking %s"), file.c_str()));
-      if (status != eProgressSuccess) {
-         break;
-      }
-
-      argv[2] = file.c_str();
-      // ToDo: do we need a try--catch around this in case a bad plug-in 
-      // fails? (JKC Nov09)
-      wxExecute((wxChar **) argv, wxEXEC_SYNC | wxEXEC_NODISABLE, NULL);
-   }
-
-   delete progress;   
+   //Choose the first for the original version which scans them all
+   //The second to selectively scan.
+   //ShowProgressDialog( longest, files );
+   return ShowPluginListDialog(  files );
 }
 
 /* static */
@@ -1891,15 +2491,3 @@ float VSTEffect::callGetParameter(long index)
 }
 
 #endif // USE_VST
-
-// Indentation settings for Vim and Emacs and unique identifier for Arch, a
-// version control system. Please do not modify past this point.
-//
-// Local Variables:
-// c-basic-offset: 3
-// indent-tabs-mode: nil
-// End:
-//
-// vim: et sts=3 sw=3
-// arch-tag: dae3d099-e1eb-494e-b8eb-8f0af7f674d2
-
