@@ -698,8 +698,10 @@ bool EffectNyquist::Process()
          //
          // MB: setlocale is not thread-safe.  Should use uselocale()
          //     if available, or fix libnyquist to be locale-independent.
-         char *prevlocale = setlocale(LC_NUMERIC, NULL);
-         setlocale(LC_NUMERIC, "C");
+         // See also http://bugzilla.audacityteam.org/show_bug.cgi?id=642#c9 
+         // for further info about this thread safety question.
+         wxString prevlocale = wxSetlocale(LC_NUMERIC, NULL);
+         wxSetlocale(LC_NUMERIC, wxT("C"));
 
          nyx_init();
          nyx_set_os_callback(StaticOSCallback, (void *)this);
@@ -712,7 +714,7 @@ bool EffectNyquist::Process()
          nyx_cleanup();
 
          // Reset previous locale
-         setlocale(LC_NUMERIC, prevlocale);
+         wxSetlocale(LC_NUMERIC, prevlocale);
 
          if (!success) {
             goto finish;
@@ -837,8 +839,8 @@ bool EffectNyquist::ProcessOne()
    }
 
    int i;
-	for (i = 0; i < mCurNumChannels; i++) {
-		mCurBuffer[i] = NULL;
+   for (i = 0; i < mCurNumChannels; i++) {
+      mCurBuffer[i] = NULL;
    }
 
    rval = nyx_eval_expression(cmd.mb_str(wxConvUTF8));
@@ -920,6 +922,13 @@ bool EffectNyquist::ProcessOne()
       return false;
    }
 
+   if (outChannels == 0) {
+      wxMessageBox(_("Nyquist returned an empty array.\n"),
+                   wxT("Nyquist"),
+                   wxOK | wxCENTRE, mParent);
+      return false;
+   }
+
    double rate = mCurTrack[0]->GetRate();
    for (i = 0; i < outChannels; i++) {
       sampleFormat format = mCurTrack[i]->GetSampleFormat();
@@ -994,7 +1003,7 @@ int EffectNyquist::StaticGetCallback(float *buffer, int channel,
 }
 
 int EffectNyquist::GetCallback(float *buffer, int ch,
-                               long start, long len, long totlen)
+                               long start, long len, long WXUNUSED(totlen))
 {
    if (mCurBuffer[ch]) {
       if ((mCurStart[ch] + start) < mCurBufferStart[ch] ||
