@@ -45,6 +45,7 @@ and ImportLOF.cpp.
 #include <wx/listimpl.cpp>
 #include "../ShuttleGui.h"
 #include "../Audacity.h"
+#include "../Project.h"
 
 #include "Import.h"
 #include "ImportPlugin.h"
@@ -327,6 +328,9 @@ int Importer::Import(wxString fName,
                      Tags *tags,
                      wxString &errorMessage)
 {
+   AudacityProject *pProj = GetActiveProject();
+   pProj->mbBusyImporting = true;
+
    ImportFileHandle *inFile = NULL;
    int numTracks = 0;
 
@@ -348,8 +352,6 @@ int Importer::Import(wxString fName,
 
    // First, add user-selected filter
    bool usersSelectionOverrides;
-   // False if override filter is not found
-   bool foundOverride = false;
    gPrefs->Read(wxT("/ExtendedImport/OverrideExtendedImportByOpenFileDialogChoice"), &usersSelectionOverrides, false);
 
    wxLogDebug(wxT("LastOpenType is %s"),type.c_str());
@@ -366,16 +368,14 @@ int Importer::Import(wxString fName,
             // This plugin corresponds to user-selected filter, try it first.
             wxLogDebug(wxT("Inserting %s"),plugin->GetPluginStringID().c_str());
             importPlugins.Insert(plugin);
-            foundOverride = true;
          }
          importPluginNode = importPluginNode->GetNext();
       }
    }
 
-   wxLogMessage(wxT("File name is %s"),fName.Lower().c_str());
-   wxLogMessage(wxT("Mime type is %s"),mime_type.Lower().c_str());
+   wxLogMessage(wxT("File name is %s"),(const char *) fName.c_str());
+   wxLogMessage(wxT("Mime type is %s"),(const char *) mime_type.Lower().c_str());
 
-   bool foundItem = false;
    for (size_t i = 0; i < mExtImportItems->Count(); i++)
    {
       ExtImportItem *item = &(*mExtImportItems)[i];
@@ -383,7 +383,7 @@ int Importer::Import(wxString fName,
       wxLogDebug(wxT("Testing extensions"));
       for (size_t j = 0; j < item->extensions.Count(); j++)
       {
-         wxLogDebug(wxT("%s"),item->extensions[j].Lower().c_str());
+         wxLogDebug(wxT("%s"), (const char *) item->extensions[j].Lower().c_str());
          if (wxMatchWild (item->extensions[j].Lower(),fName.Lower(), false))
          {
             wxLogDebug(wxT("Match!"));
@@ -419,10 +419,14 @@ int Importer::Import(wxString fName,
          wxLogDebug(wxT("Complete match!"));
          for (size_t j = 0; j < item->filter_objects.Count() && (item->divider < 0 || (int) j < item->divider); j++)
          {
+            // the filter_object can be NULL if a suitable importer was not found
+            // this happens when we recompile with --without-ffmpeg and there
+            // is still ffmpeg in prefs from previous --with-ffmpeg builds
+            if (!(item->filter_objects[j]))
+               continue;
             wxLogDebug(wxT("Inserting %s"),item->filter_objects[j]->GetPluginStringID().c_str());
             importPlugins.Append(item->filter_objects[j]);
          }
-         foundItem = true;
       }
    }
 
@@ -501,7 +505,7 @@ int Importer::Import(wxString fName,
       inFile = plugin->Open(fName);
       if ( (inFile != NULL) && (inFile->GetStreamCount() > 0) )
       {
-         wxLogMessage(wxT("Open(%s) succeeded"), fName.Lower().c_str());
+         wxLogMessage(wxT("Open(%s) succeeded"),(const char *) fName.c_str());
          // File has more than one stream - display stream selector
          if (inFile->GetStreamCount() > 1)                                                  
          {
@@ -510,6 +514,7 @@ int Importer::Import(wxString fName,
             if (ImportDlg.ShowModal() == wxID_CANCEL)
             {
                delete inFile;
+               pProj->mbBusyImporting = false;
                return 0;
             }
          }
@@ -527,16 +532,22 @@ int Importer::Import(wxString fName,
          {
             // LOF ("list-of-files") has different semantics
             if (extension.IsSameAs(wxT("lof"), false))
+            {
+               pProj->mbBusyImporting = false;
                return 1;
+            }
 
-            if (numTracks > 0) {
+            if (numTracks > 0) 
+            {
                // success!
+               pProj->mbBusyImporting = false;
                return numTracks;
             }
          }
 
          if (res == eProgressCancelled || res == eProgressFailed)
          {
+            pProj->mbBusyImporting = false;
             return 0;
          }
 
@@ -562,6 +573,7 @@ int Importer::Import(wxString fName,
          errorMessage.Printf(_("This version of Audacity was not compiled with %s support."),
                              unusableImportPlugin->
                              GetPluginFormatDescription().c_str());
+         pProj->mbBusyImporting = false;
          return 0;
       }
       unusableImporterNode = unusableImporterNode->GetNext();
@@ -573,6 +585,7 @@ int Importer::Import(wxString fName,
    // MIDI files must be imported, not opened
    if ((extension.IsSameAs(wxT("midi"), false))||(extension.IsSameAs(wxT("mid"), false))) {
       errorMessage.Printf(_("\"%s\" \nis a MIDI file, not an audio file. \nAudacity cannot open this type of file for playing, but you can\nedit it by clicking File > Import > MIDI."), fName.c_str());
+      pProj->mbBusyImporting = false;
       return 0;
    }
 #endif
@@ -583,68 +596,80 @@ int Importer::Import(wxString fName,
       if (extension.IsSameAs(wxT("cda"), false)) {
          /* i18n-hint: %s will be the filename */
          errorMessage.Printf(_("\"%s\" is an audio CD track. \nAudacity cannot open audio CDs directly. \nExtract (rip) the CD tracks to an audio format that \nAudacity can import, such as WAV or AIFF."), fName.c_str());
+         pProj->mbBusyImporting = false;
          return 0;
       }
    
       // playlist type files
       if ((extension.IsSameAs(wxT("m3u"), false))||(extension.IsSameAs(wxT("ram"), false))||(extension.IsSameAs(wxT("pls"), false))) {
          errorMessage.Printf(_("\"%s\" is a playlist file. \nAudacity cannot open this file because it only contains links to other files. \nYou may be able to open it in a text editor and download the actual audio files."), fName.c_str());
+         pProj->mbBusyImporting = false;
          return 0;
       }
       //WMA files of various forms
       if ((extension.IsSameAs(wxT("wma"), false))||(extension.IsSameAs(wxT("asf"), false))) {
          errorMessage.Printf(_("\"%s\" is a Windows Media Audio file. \nAudacity cannot open this type of file due to patent restrictions. \nYou need to convert it to a supported audio format, such as WAV or AIFF."), fName.c_str());
+         pProj->mbBusyImporting = false;
          return 0;
       }
       //AAC files of various forms (probably not encrypted)
       if ((extension.IsSameAs(wxT("aac"), false))||(extension.IsSameAs(wxT("m4a"), false))||(extension.IsSameAs(wxT("m4r"), false))||(extension.IsSameAs(wxT("mp4"), false))) {
          errorMessage.Printf(_("\"%s\" is an Advanced Audio Coding file. \nAudacity cannot open this type of file. \nYou need to convert it to a supported audio format, such as WAV or AIFF."), fName.c_str());
+         pProj->mbBusyImporting = false;
          return 0;
       }
       // encrypted itunes files
       if ((extension.IsSameAs(wxT("m4p"), false))) {
          errorMessage.Printf(_("\"%s\" is an encrypted audio file. \nThese typically are from an online music store. \nAudacity cannot open this type of file due to the encryption. \nTry recording the file into Audacity, or burn it to audio CD then \nextract the CD track to a supported audio format such as WAV or AIFF."), fName.c_str());
+         pProj->mbBusyImporting = false;
          return 0;
       }
       // Real Inc. files of various sorts
       if ((extension.IsSameAs(wxT("ra"), false))||(extension.IsSameAs(wxT("rm"), false))||(extension.IsSameAs(wxT("rpm"), false))) {
          errorMessage.Printf(_("\"%s\" is a RealPlayer media file. \nAudacity cannot open this proprietary format. \nYou need to convert it to a supported audio format, such as WAV or AIFF."), fName.c_str());
+         pProj->mbBusyImporting = false;
          return 0;
       }
    
       // Other notes-based formats
       if ((extension.IsSameAs(wxT("kar"), false))||(extension.IsSameAs(wxT("mod"), false))||(extension.IsSameAs(wxT("rmi"), false))) {
          errorMessage.Printf(_("\"%s\" is a notes-based file, not an audio file. \nAudacity cannot open this type of file. \nTry converting it to an audio file such as WAV or AIFF and \nthen import it, or record it into Audacity."), fName.c_str());
+         pProj->mbBusyImporting = false;
          return 0;
       }
    
       // MusePack files
       if ((extension.IsSameAs(wxT("mp+"), false))||(extension.IsSameAs(wxT("mpc"), false))||(extension.IsSameAs(wxT("mpp"), false))) {
          errorMessage.Printf(_("\"%s\" is a Musepack audio file. \nAudacity cannot open this type of file. \nIf you think it might be an mp3 file, rename it to end with \".mp3\" \nand try importing it again. Otherwise you need to convert it to a supported audio \nformat, such as WAV or AIFF."), fName.c_str());
+         pProj->mbBusyImporting = false;
          return 0;
       }
    
       // WavPack files
       if ((extension.IsSameAs(wxT("wv"), false))||(extension.IsSameAs(wxT("wvc"), false))) {
          errorMessage.Printf(_("\"%s\" is a Wavpack audio file. \nAudacity cannot open this type of file. \nYou need to convert it to a supported audio format, such as WAV or AIFF."), fName.c_str());
+         pProj->mbBusyImporting = false;
          return 0;
       }
    
       // AC3 files
       if ((extension.IsSameAs(wxT("ac3"), false))) {
          errorMessage.Printf(_("\"%s\" is a Dolby Digital audio file. \nAudacity cannot currently open this type of file. \nYou need to convert it to a supported audio format, such as WAV or AIFF."), fName.c_str());
+         pProj->mbBusyImporting = false;
          return 0;
       }
    
       // Speex files
       if ((extension.IsSameAs(wxT("spx"), false))) {
          errorMessage.Printf(_("\"%s\" is an Ogg Speex audio file. \nAudacity cannot currently open this type of file. \nYou need to convert it to a supported audio format, such as WAV or AIFF."), fName.c_str());
+         pProj->mbBusyImporting = false;
          return 0;
       }
    
       // Video files of various forms
       if ((extension.IsSameAs(wxT("mpg"), false))||(extension.IsSameAs(wxT("mpeg"), false))||(extension.IsSameAs(wxT("avi"), false))||(extension.IsSameAs(wxT("wmv"), false))||(extension.IsSameAs(wxT("rv"), false))) {
          errorMessage.Printf(_("\"%s\" is a video file. \nAudacity cannot currently open this type of file. \nYou need to extract the audio to a supported format, such as WAV or AIFF."), fName.c_str());
+         pProj->mbBusyImporting = false;
          return 0;
       }
 
@@ -670,6 +695,7 @@ int Importer::Import(wxString fName,
       errorMessage.Printf(_("Audacity recognized the type of the file '%s'.\nImporters supposedly supporting such files are:\n%s,\nbut none of them understood this file format."),fName.c_str(), pluglist.c_str());
    }
 
+   pProj->mbBusyImporting = false;
    return 0;
 }
 
@@ -713,7 +739,7 @@ ImportStreamDialog::~ImportStreamDialog()
 
 }
 
-void ImportStreamDialog::OnOk(wxCommandEvent &event)
+void ImportStreamDialog::OnOk(wxCommandEvent & WXUNUSED(event))
 {
    wxArrayInt selitems;
    int sels = StreamList->GetSelections(selitems);
@@ -722,19 +748,8 @@ void ImportStreamDialog::OnOk(wxCommandEvent &event)
    EndModal( wxID_OK );
 }
 
-void ImportStreamDialog::OnCancel(wxCommandEvent &event)
+void ImportStreamDialog::OnCancel(wxCommandEvent & WXUNUSED(event))
 {
    EndModal( wxID_CANCEL );
 }
 
-// Indentation settings for Vim and Emacs and unique identifier for Arch, a
-// version control system. Please do not modify past this point.
-//
-// Local Variables:
-// c-basic-offset: 3
-// indent-tabs-mode: nil
-// End:
-//
-// vim: et sts=3 sw=3
-// arch-tag: 702e6bd3-b26c-424f-9d6a-c88b565ea143
-
