@@ -174,7 +174,7 @@ class ToolFrame:public wxFrame
    //
    // Handle frame paint events
    //
-   void OnPaint( wxPaintEvent & event )
+   void OnPaint( wxPaintEvent & WXUNUSED(event) )
    {
       wxPaintDC dc( this );
       wxSize sz = GetSize();
@@ -264,7 +264,7 @@ class ToolFrame:public wxFrame
       }
    }
 
-   void OnCaptureLost( wxMouseCaptureLostEvent & event )
+   void OnCaptureLost( wxMouseCaptureLostEvent & WXUNUSED(event) )
    {
       if( HasCapture() )
       {
@@ -824,6 +824,7 @@ bool ToolManager::IsVisible( int type )
 
    return t->IsVisible();
 
+#if 0
    // If toolbar is floating
    if( !t->IsDocked() )
    {
@@ -833,6 +834,7 @@ bool ToolManager::IsVisible( int type )
 
    // Return state of docked toolbar
    return t->IsShown();
+#endif
 }
 
 //
@@ -1200,14 +1202,3 @@ void ToolManager::OnGrabber( GrabberEvent & event )
    mLastState = wxGetKeyState( WXK_SHIFT );
    mTimer.Start( 100 );
 }
-
-// Indentation settings for Vim and Emacs and unique identifier for Arch, a
-// version control system. Please do not modify past this point.
-//
-// Local Variables:
-// c-basic-offset: 3
-// indent-tabs-mode: nil
-// End:
-//
-// vim: et sts=3 sw=3
-// arch-tag: 2f4ec75c-bdb7-4889-96d-5d00abc41027
