@@ -172,7 +172,7 @@ ExpandingToolBar::~ExpandingToolBar()
 {
 }
 
-void ExpandingToolBar::OnSize(wxSizeEvent &evt)
+void ExpandingToolBar::OnSize(wxSizeEvent & WXUNUSED(event))
 {
    if (mFrameParent || mDialogParent || mAreaParent)
       return;
@@ -212,7 +212,7 @@ void ExpandingToolBar::OnSize(wxSizeEvent &evt)
    }
 }
 
-void ExpandingToolBar::OnToggle(wxCommandEvent &evt)
+void ExpandingToolBar::OnToggle(wxCommandEvent & WXUNUSED(event))
 {
    if (mIsExpanded)
       Collapse();
@@ -464,7 +464,7 @@ void ExpandingToolBar::MoveDrawer(wxSize prevSize)
    }
 }
 
-void ExpandingToolBar::OnTimer(wxTimerEvent &evt)
+void ExpandingToolBar::OnTimer(wxTimerEvent & WXUNUSED(event))
 {
    if (mAutoExpand && msNoAutoExpandStack==0 &&
        IsCursorInWindow())
@@ -714,14 +714,14 @@ void ToolBarGrabber::OnMouse(wxMouseEvent &event)
       Refresh(false);
 }
 
-void ToolBarGrabber::OnPaint(wxPaintEvent &evt)
+void ToolBarGrabber::OnPaint(wxPaintEvent & WXUNUSED(event))
 {
    wxPaintDC dc(this);
 
    mImageRoll[mState].Draw(dc, GetClientRect());
 }
 
-void ToolBarGrabber::OnSize(wxSizeEvent &evt)
+void ToolBarGrabber::OnSize(wxSizeEvent & WXUNUSED(event))
 {
    Refresh(false);
 }
@@ -893,7 +893,6 @@ bool ToolBarArea::ExpandRow(int rowIndex)
    for(i=0; i<(int)mChildArray.GetCount(); i++)
       if (mRowArray[i] == rowIndex) {
          ExpandingToolBar *child = mChildArray[i];
-         wxPoint childPos = child->GetPosition();
          wxSize childMin = child->GetMinSize();
          wxSize childMax = child->GetMaxSize();
 
@@ -943,17 +942,16 @@ void ToolBarArea::LayoutOne(int childIndex)
    wxSize area = GetClientSize();
    ExpandingToolBar *child = mChildArray[childIndex];
    wxSize childMin = child->GetMinSize();
-   wxSize childMax = child->GetMaxSize();
 
    if (childIndex == 0) {
       mRowArray[childIndex] = 0;
       mChildArray[childIndex]->SetSize(0, 0, childMin.x, childMin.y);
       ExpandRow(0);
 
+      #if 0
       wxPoint p = mChildArray[childIndex]->GetPosition();
       wxSize s = mChildArray[childIndex]->GetSize();
 
-      #if 0
       printf("ToolBar %d moved to row %d at (%d, %d), size (%d x %d)\n",
              childIndex, mRowArray[childIndex],
              p.x, p.y, s.x, s.y);
@@ -1002,10 +1000,10 @@ void ToolBarArea::LayoutOne(int childIndex)
    // allowed to redo the layout.
    mLastLayoutSize = area;
 
+   #if 0
    wxPoint p = mChildArray[childIndex]->GetPosition();
    wxSize s = mChildArray[childIndex]->GetSize();
 
-   #if 0
    printf("ToolBar %d moved to row %d at (%d, %d), size (%d x %d)\n",
           childIndex, mRowArray[childIndex],
           p.x, p.y, s.x, s.y);
@@ -1105,7 +1103,7 @@ void ToolBarArea::Fit(bool horizontal, bool vertical)
    }
 }
 
-void ToolBarArea::OnSize(wxSizeEvent &evt)
+void ToolBarArea::OnSize(wxSizeEvent & WXUNUSED(event))
 {
    if (mInOnSize)
       return;
@@ -1283,14 +1281,3 @@ void ToolBarArea::SetCapturedChild(ExpandingToolBar *child)
 {
    mCapturedChild = child;
 }
-
-// Indentation settings for Vim and Emacs.
-// Please do not modify past this point.
-//
-// Local Variables:
-// c-basic-offset: 3
-// indent-tabs-mode: nil
-// End:
-//
-// vim: et sts=3 sw=3
-// 
