@@ -1470,14 +1470,14 @@ ProgressDialog::SetMessage(const wxString & message)
 }
 
 void
-ProgressDialog::OnCancel(wxCommandEvent & e)
+ProgressDialog::OnCancel(wxCommandEvent & WXUNUSED(event))
 {
    FindWindowById(wxID_CANCEL, this)->Disable();
    mCancel = true;
 }
 
 void
-ProgressDialog::OnStop(wxCommandEvent & e)
+ProgressDialog::OnStop(wxCommandEvent & WXUNUSED(event))
 {
    FindWindowById(wxID_OK, this)->Disable();
    mCancel = false;
@@ -1576,15 +1576,3 @@ int TimerProgressDialog::Update(const wxString & message /*= wxEmptyString*/)
 
    return eProgressSuccess;
 }
-
-
-// Indentation settings for Vim and Emacs and unique identifier for Arch, a
-// version control system. Please do not modify past this point.
-//
-// Local Variables:
-// c-basic-offset: 3
-// indent-tabs-mode: nil
-// End:
-//
-// vim: et sts=3 sw=3
-// arch-tag: 2f4ec75c-bdb7-4889-96d1-5d00abc41027
