@@ -900,12 +900,12 @@ void TimeTextCtrl::Fit()
    SetInitialSize(sz);
 }
 
-void TimeTextCtrl::OnErase(wxEraseEvent & event)
+void TimeTextCtrl::OnErase(wxEraseEvent & WXUNUSED(event))
 {
    // Ignore it to prevent flashing
 }
 
-void TimeTextCtrl::OnPaint(wxPaintEvent &event)
+void TimeTextCtrl::OnPaint(wxPaintEvent & WXUNUSED(event))
 {
    wxPaintDC dc(this);
    bool focused = (FindFocus() == this);
@@ -1482,7 +1482,7 @@ TimeTextCtrlAx::~TimeTextCtrlAx()
 // or > 0 (the action for a child).
 // Return wxACC_NOT_SUPPORTED if there is no default action for this
 // window (e.g. an edit control).
-wxAccStatus TimeTextCtrlAx::DoDefaultAction(int childId)
+wxAccStatus TimeTextCtrlAx::DoDefaultAction(int WXUNUSED(childId))
 {
    return wxACC_NOT_SUPPORTED;
 }
@@ -1516,7 +1516,7 @@ wxAccStatus TimeTextCtrlAx::GetChildCount(int *childCount)
 // object, not what the object does as a result. For example, a
 // toolbar button that prints a document has a default action of
 // "Press" rather than "Prints the current document."
-wxAccStatus TimeTextCtrlAx::GetDefaultAction(int childId, wxString *actionName)
+wxAccStatus TimeTextCtrlAx::GetDefaultAction(int WXUNUSED(childId), wxString *actionName)
 {
    actionName->Clear();
 
@@ -1524,7 +1524,7 @@ wxAccStatus TimeTextCtrlAx::GetDefaultAction(int childId, wxString *actionName)
 }
 
 // Returns the description for this object or a child.
-wxAccStatus TimeTextCtrlAx::GetDescription(int childId, wxString *description)
+wxAccStatus TimeTextCtrlAx::GetDescription(int WXUNUSED(childId), wxString *description)
 {
    description->Clear();
 
@@ -1544,7 +1544,7 @@ wxAccStatus TimeTextCtrlAx::GetFocus(int *childId, wxAccessible **child)
 }
 
 // Returns help text for this object or a child, similar to tooltip text.
-wxAccStatus TimeTextCtrlAx::GetHelpText(int childId, wxString *helpText)
+wxAccStatus TimeTextCtrlAx::GetHelpText(int WXUNUSED(childId), wxString *helpText)
 {
 // removed help text, as on balance it's more of an irritation than useful
 #if 0    // was #if wxUSE_TOOLTIPS
@@ -1563,7 +1563,7 @@ wxAccStatus TimeTextCtrlAx::GetHelpText(int childId, wxString *helpText)
 
 // Returns the keyboard shortcut for this object or child.
 // Return e.g. ALT+K
-wxAccStatus TimeTextCtrlAx::GetKeyboardShortcut(int childId, wxString *shortcut)
+wxAccStatus TimeTextCtrlAx::GetKeyboardShortcut(int WXUNUSED(childId), wxString *shortcut)
 {
    shortcut->Clear();
 
@@ -1668,7 +1668,7 @@ wxAccStatus TimeTextCtrlAx::GetName(int childId, wxString *name)
 }
 
 // Returns a role constant.
-wxAccStatus TimeTextCtrlAx::GetRole(int childId, wxAccRole *role)
+wxAccStatus TimeTextCtrlAx::GetRole(int WXUNUSED(childId), wxAccRole *role)
 {
    *role = wxROLE_SYSTEM_STATICTEXT;
    return wxACC_OK;
@@ -1682,13 +1682,13 @@ wxAccStatus TimeTextCtrlAx::GetRole(int childId, wxAccRole *role)
 // - an integer representing the selected child element,
 //   or 0 if this object is selected (GetType() == wxT("long"))
 // - a "void*" pointer to a wxAccessible child object
-wxAccStatus TimeTextCtrlAx::GetSelections(wxVariant *selections)
+wxAccStatus TimeTextCtrlAx::GetSelections(wxVariant * WXUNUSED(selections))
 {
    return wxACC_NOT_IMPLEMENTED;
 }
 
 // Returns a state constant.
-wxAccStatus TimeTextCtrlAx::GetState(int childId, long *state)
+wxAccStatus TimeTextCtrlAx::GetState(int WXUNUSED(childId), long *state)
 {
    *state = wxACC_STATE_SYSTEM_FOCUSABLE;
    *state |= (mCtrl == wxWindow::FindFocus() ? wxACC_STATE_SYSTEM_FOCUSED : 0);
@@ -1698,23 +1698,9 @@ wxAccStatus TimeTextCtrlAx::GetState(int childId, long *state)
 
 // Returns a localized string representing the value for the object
 // or child.
-wxAccStatus TimeTextCtrlAx::GetValue(int childId, wxString *strValue)
+wxAccStatus TimeTextCtrlAx::GetValue(int WXUNUSED(childId), wxString * WXUNUSED(strValue))
 {
    return wxACC_NOT_IMPLEMENTED;
 }
 
 #endif
-
-
-// Indentation settings for Vim and Emacs.
-// Please do not modify past this point.
-//
-// Local Variables:
-// c-basic-offset: 3
-// indent-tabs-mode: nil
-// End:
-//
-// vim: et sts=3 sw=3
-// 
-
-
